USE ASLogger
GO
IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME='tbl_Calls' AND COLUMN_NAME = 'Direction') 
	BEGIN
		ALTER TABLE tbl_Calls
		ADD Direction tinyint null 	 
	END
GO

----------------------------------------------------------------------------------------------
IF NOT EXISTS (SELECT * FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME='tbl_Calls' AND COLUMN_NAME = 'CallAnswered') 
	BEGIN
		ALTER TABLE tbl_Calls
		ADD CallAnswered tinyint null 	 
	END
GO

-----------------------------------------------------------------------------------------------
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[fn_RemoveDuplicateNumber]'))
	drop FUNCTION [dbo].fn_RemoveDuplicateNumber
GO

CREATE FUNCTION [dbo].[fn_RemoveDuplicateNumber] (@strDB CHAR(64), @strNew CHAR(64))
	RETURNS VARCHAR(128)
AS
BEGIN
	DECLARE @RETVAL VARCHAR(128)
	SET @RETVAL = ''
	IF @strDB = @strNew
		BEGIN
			SET @RETVAL = @strNew
		END
	ELSE
		BEGIN		
			SET @RETVAL = LTRIM(RTRIM(@strDB)) + LTRIM(RTRIM(@strNew))
		END
	RETURN @RETVAL	
END
GO

-------------------------------------------------------------------------------------------------
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_AddBookMark]'))
	drop proc [dbo].sp_AddBookMark
GO
CREATE  PROC [dbo].[sp_AddBookMark]
	@CallID as VARCHAR(32), 
	@BookMarkPos as bigint, 
	@BookMarkText as VARCHAR(300)
AS
	insert into tbl_BookMark(CallID, BookMarkPos, BookMarkText) values (@CallID, @BookMarkPos, @BookMarkText)
	update tbl_Calls set BookMarkFlag = 1 where CallID = @CallID
GO
-------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_DeleteDuplicateMissedCalls]'))
	drop proc [dbo].sp_DeleteDuplicateMissedCalls
GO
CREATE PROC [dbo].[sp_DeleteDuplicateMissedCalls]	
	@CallID AS VARCHAR(32),
	@Starttime AS VARCHAR(32),
	@CallerID AS VARCHAR(32)
AS
BEGIN
	DECLARE @myCounter int = 0
	SELECT @myCounter=count(*) from tbl_calls where CallID != @CallID AND Starttime = @Starttime AND CallerID = @CallerID AND CallAnswered != 1
	IF( @myCounter > 0 )
		BEGIN
			DELETE FROM tbl_Calls where CallID = @CallID
			SELECT @myCounter AS UpdateRec
		END
END
GO
-------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_FindCalls]'))
	drop proc [dbo].sp_FindCalls
GO
CREATE PROC [dbo].[sp_FindCalls]
	@BUF_Name AS VARCHAR(32),
	@s_Date AS CHAR(8),
	@e_Date AS CHAR(8),
	@s_Time AS CHAR(6),
	@e_Time AS CHAR(6),
	@s_Dur AS INT = 0,
	@e_Dur AS INT = 0,
	@TopCount AS INT = 100,		-- TOTAL RECORDS TO SEARCH, SEARCH WILL STOP ON REACHING TOP COUNT
	@optionSTR AS TEXT = '',
	@SHOWCALL AS CHAR(1) = '1',	-- 0 = DON'T SHOW CALL, 1 = SHOW CALL
	@CallStatusFlag AS TINYINT = 0, -- 0 = ALL CALL, 1 = CRITICAL CALL, 2 = START MARKED CALL
	@LODFlag AS TINYINT = 0, -- 0 = ALL CALL, 1 = LOG ON DEMAND CALL
	@RatingLevel AS TINYINT = 0, -- 0 = ALL CALL, 1-5 = Rating Level
	@CallDirection AS TINYINT = 0, -- 0 = ALL CALL, 1 = INBOUND CALL, 2 = OUTBOUND, 3 = UNKNOWN
	@BookMarkFlag AS TINYINT = 0, -- 0 = ALL CALL, 1 = BOOKMARKED CALL
	@CallAnswered AS TINYINT = 2, -- 2 = ALL CALL, 1 = Answered CALLs, 0 = Unanswered calls
	@FIELDSEARCH AS VARCHAR(256) = '',--Field Search Text. if this field will be empty then no text search will be performed
	@FIELD AS VARCHAR(100) = '',--IF this value will be empty then all callumns will be searched for @FIELDSEARCH	
	@UserNum AS VARCHAR(10) = ''
AS
BEGIN

	SET NOCOUNT ON
	
	DECLARE @myBUF_t VARCHAR(256)
	DECLARE @insertSTR NVARCHAR(4000)
	DECLARE @selectSTR NVARCHAR(4000)
	DECLARE @fromSTR NVARCHAR(4000)
	DECLARE @whereSTR VARCHAR(4000)
	DECLARE @sqlSTR NVARCHAR(4000)
	DECLARE @myRecords int
	DECLARE @myCounter int
	DECLARE @TotTemCounter int
	DECLARE @RemCounter int
	DECLARE @myDBName VARCHAR(32)
	DECLARE @mySQLCmdText VARCHAR(4096)
	DECLARE @ReplaceInsert VARCHAR(4096)
	DECLARE @ReplaceFrom VARCHAR(4096)
	DECLARE @ReplaceWhere VARCHAR(4096)
	DECLARE @ReplaceSelect VARCHAR(4096)
	DECLARE @PARENTHESIS AS TINYINT = 0
	/*first of all obtain the databases that contain the records of user selected date & time range*/
	CREATE TABLE  #tempRequiredDatabases (TempRecordIndex INT PRIMARY KEY IDENTITY(0, 1),[TempDatabaseName] [char] (32) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL)
	 
	INSERT INTO #tempRequiredDatabases(TempDatabaseName) select [db_name] from tbl_Database where last_record_datetime>=@s_Date + @s_Time and first_record_datetime<=@e_Date + @e_Time order by db_chain_id  asc
	
	SELECT @myRecords=count(TempRecordIndex) from #tempRequiredDatabases

	if(@myRecords IS NULL OR @myRecords < 1)
	BEGIN
		SELECT @myRecords=count(*) from tbl_Database
		IF(@myRecords IS NULL OR @myRecords < 1)
			BEGIN
				insert into tbl_Database(db_chain_id,db_name,first_record_datetime,last_record_datetime,db_status,db_created_on_datetime) values(1, 'ASLogger', (select min(StartTime) from tbl_Calls), (select max(StartTime) from tbl_Calls), 'A', dbo.fn_getDateTimeSTR(GetDate()))
				INSERT INTO #tempRequiredDatabases(TempDatabaseName) select [db_name] from tbl_Database where last_record_datetime>=@s_Date + @s_Time and first_record_datetime<=@e_Date + @e_Time order by db_chain_id  asc
				SELECT @myRecords=count(TempRecordIndex) from #tempRequiredDatabases
				IF(@myRecords IS NULL OR @myRecords < 1)
				BEGIN 
					DROP TABLE #tempRequiredDatabases
					RETURN 0;
				END
			END
		ELSE
			BEGIN 
				DROP TABLE #tempRequiredDatabases
				RETURN 0;
			END
	END
	
	SET @myBUF_t = @BUF_Name

	DECLARE @SUBSTR VARCHAR(2)
	SET @SUBSTR = LEFT(@myBUF_t, 2) 
	BEGIN TRY
	IF @SUBSTR = '##'
		BEGIN
			If exists(select  COUNT(*) from tempdb.dbo.sysobjects o where o.xtype in ('U') and o.name = @myBUF_t)
			BEGIN
				SET @sqlSTR = 'DROP TABLE ' + @myBUF_t
				EXEC(@sqlSTR)
			END
		END
	ELSE
		BEGIN
			IF(object_id(@myBUF_t) IS NOT NULL)
			BEGIN
				SET @sqlSTR = 'DROP TABLE ' + @myBUF_t
				EXEC(@sqlSTR)
			END
		END
	END TRY
	BEGIN CATCH
	END CATCH; 
	
	SET @sqlSTR = 'CREATE TABLE ' + @myBUF_t + char(13)
	SET @sqlSTR = @sqlSTR + '(idx INT PRIMARY KEY IDENTITY(1, 1),' + char(13)
	SET @sqlSTR = @sqlSTR + 'CallIDIDX CHAR(32),' + char(13)	
	SET @sqlSTR = @sqlSTR + 'UserNameIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'GroupNameIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'ExtIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'ExtNameIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'CallTimeIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'CallDurationIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'CallerIDX varchar(128),' + char(13)
	SET @sqlSTR = @sqlSTR + 'CalledIDX varchar(128),' + char(13)
	SET @sqlSTR = @sqlSTR + 'CallTagIDX nvarchar(100),' + char(13)
	SET @sqlSTR = @sqlSTR + 'BookmarksIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'RetainValueIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'CallCommentIDX varchar(240),' + char(13)
	SET @sqlSTR = @sqlSTR + 'ROD_CustNameIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'ROD_CustNumIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'ROD_CustInfo2IDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'ROD_CustInfo3IDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'ROD_CustInfo4IDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'ANI_NAMEIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'ANI_PHIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'ANI_DETAILSIDX nvarchar(256),' + char(13)	
	SET @sqlSTR = @sqlSTR + 'StartDayIDX CHAR(8),' + char(13)
	SET @sqlSTR = @sqlSTR + 'StartTimeIDX CHAR(6),' + char(13)
	SET @sqlSTR = @sqlSTR + 'RecorderIPIDX varchar(64),' + char(13)
	SET @sqlSTR = @sqlSTR + 'InHDDIDX char(2),' + char(13)
	SET @sqlSTR = @sqlSTR + 'CallIndexIDX int,' + char(13)
	SET @sqlSTR = @sqlSTR + 'BackupIDIDX int,' + char(13)		
	SET @sqlSTR = @sqlSTR + 'AudioFileNameIDX VARCHAR(32),' + char(13)
	SET @sqlSTR = @sqlSTR + 'VideoFileNameIDX varchar(100),' + char(13)
	SET @sqlSTR = @sqlSTR + 'PlayServerPortIDX int,' + char(13)
	SET @sqlSTR = @sqlSTR + 'CallStatusFlagIDX tinyint,' + char(13)
	SET @sqlSTR = @sqlSTR + 'LODFlagIDX tinyint,' + char(13)
	SET @sqlSTR = @sqlSTR + 'BookMarkFlagIDX tinyint,' + char(13)
	SET @sqlSTR = @sqlSTR + 'CallRating tinyint,' + char(13)
	SET @sqlSTR = @sqlSTR + 'DirectionIDX tinyint,' + char(13)
	SET @sqlSTR = @sqlSTR + 'EvalStatusIDX tinyint' + char(13)	
	SET @sqlSTR = @sqlSTR + ')' + char(13)
	
	EXEC(@sqlSTR)

	EXEC('
		CREATE INDEX IX_' + @myBUF_t + '_StartTime ON ' + @myBUF_t + ' (StartDayIDX DESC, StartTimeIDX DESC) WITH  FILLFACTOR = 80 ON [PRIMARY]
	')

	IF(@@ERROR<>0)
	BEGIN
		SET @sqlSTR = 'SearchResult create failed...' + @sqlSTR
		RAISERROR(@sqlSTR, 16, 1)
		RETURN -1
	END
	
	SET @selectSTR = 'CI.CallID AS [CallIDIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'A.UserName AS [UserNameIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'ISNULL(G.GroupName, ''-'') AS [GroupNameIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'ISNULL(CI.Ext, ''-'') AS [ExtIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'ISNULL(EI.ExtName, ''-'') AS [ExtNameIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'dbo.fn_ConvertDate(CI.StartTime) AS [CallTimeIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'dbo.fn_IntToTimeFix(CI.Duration/1000) AS [CallDurationIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'ISNULL(CI.CallerID, ''-'') AS [CallerIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'ISNULL(CI.CalledID, ''-'') AS [CalledIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'ISNULL(CI.Tag1, ''-'') AS [CallTagIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'ISNULL(dbo.BOOKMARKSFUNC(CI.CallID), ''-'') AS [BookmarksIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'ISNULL(CI.RetainValue, ''-'') AS [RetainValueIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'CI.CALL_COMMENT AS [CallCommentIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'ISNULL(CI.CustName, ''-'') AS [ROD_CustNameIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'ISNULL(CI.ANI, ''-'') AS [ROD_CustNumIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'ISNULL(CI.Tag2, ''-'') AS [ROD_CustInfo2IDX],' + char(13)
	SET @selectSTR = @selectSTR + 'ISNULL(CI.Tag3, ''-'') AS [ROD_CustInfo3IDX],' + char(13)
	SET @selectSTR = @selectSTR + 'ISNULL(CI.Tag4, ''-'') AS [ROD_CustInfo4IDX],' + char(13)
	SET @selectSTR = @selectSTR + 'ISNULL(CI.ANI_NAME, ''-'') AS [ANI_NAMEIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'ISNULL(CI.ANI_PH, ''-'') AS [ANI_PHIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'LEFT(CI.ANI_DETAILS,256) AS [ANI_DETAILSIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'LEFT(CI.StartTime,8) AS [StartDayIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'RIGHT(CI.StartTime, 6) AS [StartTimeIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'RI.RecIP AS [RecorderIPIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'CI.InHDD AS [InHDDIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'CI.CallIndex AS [CallIndexIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'CI.BackupID AS [BackupIDIDX],' + char(13)	
	SET @selectSTR = @selectSTR + 'CI.FileName AS [AudioFileNameIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'CI.Screen_Rec_File AS [VideoFileNameIDX],' + char(13)	
	SET @selectSTR = @selectSTR + 'RI.PlaybackPort AS [PlayServerPortIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'CI.CallStatusFlag AS [CallStatusFlagIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'CI.LODFlag AS [LODFlagIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'CI.BookMarkFlag AS [BookMarkFlagIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'CI.CallRating AS [CallRating],' + char(13)
	SET @selectSTR = @selectSTR + 'ISNULL(CI.Direction, ''3'') AS [DirectionIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'dbo.fn_IsCallEvaluated('+@UserNum+', CI.CallID) AS [EvalStatusIDX]' + char(13)
	SET @fromSTR = '[#ASLogger#].[dbo].[tbl_Calls] CI LEFT JOIN tbl_channel EI ON CI.Ext = EI.Ext AND EI.Status = 1' + char(13)
	SET @fromSTR = @fromSTR + 'LEFT JOIN tbl_User A ON CI.UserNum = A.UserNum' + char(13)
	SET @fromSTR = @fromSTR + 'LEFT JOIN tbl_Loggers RI ON CI.RecID = RI.RecID  AND RI.Status=1 ' + char(13)
	SET @fromSTR = @fromSTR + 'LEFT JOIN tbl_Group G ON CI.GroupNum = G.GroupNum' + char(13)
	 --CONVERT(int, @m/1000 + 1900)
	-- WHERE CLAUSE.
	--SET @whereSTR = '(CI.StartTime BETWEEN ''' + @s_Date + @s_Time + ''' AND ''' + @e_Date + @e_Time + ''')' + char(13)	
	SET @whereSTR = ' dbo.FilterDateTime(LEFT(CI.StartTime,8), RIGHT(CI.StartTime, 6), '+@s_Date+', '+@s_Time+', '+@e_Date+', '+@e_Time+') > 0 ' + char(13)	
	
	IF(@s_Dur > 0 OR @e_Dur > 0)
		BEGIN
			SET @whereSTR = @whereSTR + 'AND' + char(13)
			SET @whereSTR = @whereSTR +  'CI.Duration BETWEEN ' + CONVERT(VARCHAR, @s_Dur) + ' AND ' + CONVERT(VARCHAR, @e_Dur)  + char(13)
		END
	ELSE
		BEGIN
			IF(@CallAnswered = 2 OR @CallAnswered = 1)
			BEGIN
				SET @whereSTR = @whereSTR + 'AND' + char(13)			
				SET @whereSTR = @whereSTR +  'CI.Duration > 0'  + char(13)
			END
		END
	IF(@CallDirection > 0)
		BEGIN
			SET @whereSTR = @whereSTR + 'AND' + char(13)
			SET @whereSTR = @whereSTR +  'CI.Direction = ' + CAST ( @CallDirection AS VARCHAR(1) )  + char(13)
		END
	IF(@CallAnswered < 2)
		BEGIN
			SET @whereSTR = @whereSTR + 'AND' + char(13)
			SET @whereSTR = @whereSTR +  'CI.CallAnswered = ' + CAST ( @CallAnswered AS VARCHAR(1) )  + char(13)
		END
	SET @whereSTR = @whereSTR + 'AND' + char(13)
	SET @whereSTR = @whereSTR +  'CI.IsShow = ''' + @SHOWCALL + '''' + char(13)

	IF @CallStatusFlag = 3
		BEGIN
			SET @whereSTR = @whereSTR + 'AND' + char(13)
			SET @PARENTHESIS = 1
			SET @whereSTR = @whereSTR +  '( CI.CallStatusFlag > 0 ' + char(13)
		END
	ELSE IF @CallStatusFlag > 0
		BEGIN
			SET @whereSTR = @whereSTR + 'AND' + char(13)
			SET @PARENTHESIS = 1
			SET @whereSTR = @whereSTR +  '( CI.CallStatusFlag = '+ CAST ( @CallStatusFlag AS VARCHAR(1) ) + char(13)
		END
	IF @LODFlag > 0
		BEGIN
			IF @PARENTHESIS = 1	
				BEGIN		
					SET @whereSTR = @whereSTR + 'OR' + char(13)
				END
			ELSE
				BEGIN		
					SET @PARENTHESIS = 1
					SET @whereSTR = @whereSTR + 'AND ( ' + char(13)
				END				
			SET @whereSTR = @whereSTR +  ' CI.LODFlag = '+ CAST ( @LODFlag AS VARCHAR(1) ) + char(13)
		END		
	IF @BookMarkFlag > 0
		BEGIN
			IF @PARENTHESIS = 1	
				BEGIN		
					SET @whereSTR = @whereSTR + 'OR' + char(13)
				END
			ELSE
				BEGIN		
					SET @PARENTHESIS = 1
					SET @whereSTR = @whereSTR + 'AND ( ' + char(13)
				END
			SET @whereSTR = @whereSTR +  ' CI.BookMarkFlag = '+ CAST ( @BookMarkFlag AS VARCHAR(1) ) + char(13)
		END	
	
	IF @PARENTHESIS = 1	
		BEGIN		
			SET @whereSTR = @whereSTR + ')' + char(13)
		END
	IF @RatingLevel > 0
		BEGIN
			SET @whereSTR = @whereSTR + 'AND ' + char(13)
			SET @whereSTR = @whereSTR +  ' CI.CallRating = '+ CAST ( @RatingLevel AS VARCHAR(1) ) + char(13)
		END				
	IF @FIELDSEARCH <> '' AND @FIELD <> '' AND @FIELD <> 'BookMarkText'
		BEGIN
			SET @whereSTR = @whereSTR + 'AND' + char(13)
			SET @whereSTR = @whereSTR +  ' CI.' + @FIELD + ' LIKE '''+ '%' +@FIELDSEARCH + '%' + '''' + char(13)
		END
	
	ELSE IF @FIELDSEARCH <> '' AND @FIELD <> '' AND @FIELD = 'BookMarkText'
		BEGIN
			SET @whereSTR = @whereSTR + 'AND' + char(13)
			SET @whereSTR = @whereSTR +  ' dbo.BOOKMARKSFUNC(CI.CallID)  LIKE '''+ '%' +@FIELDSEARCH + '%' + '''' + char(13)
		END
	ELSE IF @FIELDSEARCH <> '' AND @FIELD = ''
		BEGIN
			SET @whereSTR = @whereSTR + 'AND' + char(13)
			SET @whereSTR = @whereSTR +  ' (dbo.BOOKMARKSFUNC(CI.CallID) LIKE '''+ '%' +@FIELDSEARCH + '%' + '''' + char(13)
			SET @whereSTR = @whereSTR + 'OR' + char(13)
			
			SET @whereSTR = @whereSTR +  ' CI.FileName LIKE '''+ '%' +@FIELDSEARCH + '%' + '''' + char(13)
			--SET @whereSTR = @whereSTR + 'OR' + char(13)
			--SET @whereSTR = @whereSTR +  ' CI.DTMP LIKE '''+ '%' +@FIELDSEARCH + '%' + '''' + char(13)
			SET @whereSTR = @whereSTR + 'OR' + char(13)
			SET @whereSTR = @whereSTR +  ' CI.CustName LIKE '''+ '%' +@FIELDSEARCH + '%' + '''' + char(13)
			SET @whereSTR = @whereSTR + 'OR' + char(13)
			SET @whereSTR = @whereSTR +  ' CI.ANI LIKE '''+ '%' +@FIELDSEARCH + '%' + '''' + char(13)
			SET @whereSTR = @whereSTR + 'OR' + char(13)
			SET @whereSTR = @whereSTR +  ' CI.ANI_PH LIKE '''+ '%' +@FIELDSEARCH + '%' + '''' + char(13)
			SET @whereSTR = @whereSTR + 'OR' + char(13)
			SET @whereSTR = @whereSTR +  ' CI.CalledID LIKE '''+ '%' +@FIELDSEARCH + '%' + '''' + char(13)
			SET @whereSTR = @whereSTR + 'OR' + char(13)
			SET @whereSTR = @whereSTR +  ' CI.CallerID LIKE '''+ '%' +@FIELDSEARCH + '%' + '''' + char(13)
			SET @whereSTR = @whereSTR + 'OR' + char(13)			
			SET @whereSTR = @whereSTR +  ' CI.ANI_NAME LIKE '''+ '%' +@FIELDSEARCH + '%' + '''' + char(13)
			SET @whereSTR = @whereSTR + 'OR' + char(13)
			SET @whereSTR = @whereSTR +  ' CI.ANI_DETAILS LIKE '''+ '%' +@FIELDSEARCH + '%' + '''' + char(13)
			SET @whereSTR = @whereSTR + 'OR' + char(13)
			SET @whereSTR = @whereSTR +  ' CI.CALL_COMMENT LIKE '''+ '%' +@FIELDSEARCH + '%' + '''' + char(13)
			SET @whereSTR = @whereSTR + ')' + char(13)
		END	
	SET @myCounter=0
	SET @TotTemCounter = 0
	set @RemCounter = @TopCount
	
	DECLARE @InsertCount INT
	SET @InsertCount = 0
	WHILE( @myCounter < @myRecords )					
	BEGIN
		
		SELECT @myDBName=TempDatabaseName from #tempRequiredDatabases where TempRecordIndex=@myCounter
		SET @ReplaceFrom =  REPLACE(@fromSTR, '#ASLogger#', LTRIM(RTRIM(@myDBName)))
		SET @ReplaceWhere =  REPLACE(@whereSTR, '#ASLogger#', LTRIM(RTRIM(@myDBName)))
		SET @ReplaceSelect =  REPLACE(@selectSTR, '#ASLogger#', LTRIM(RTRIM(@myDBName)))
		
		IF(@TopCount  > 0)
			BEGIN		
				EXEC(
					'INSERT INTO ' + @myBUF_t
					+ ' SELECT TOP '+ @RemCounter + ' ' 
					+ @ReplaceSelect + ' FROM ' 
					+ @ReplaceFrom + ' WHERE '
					+ @ReplaceWhere + ' '
					+ @optionSTR + ' ORDER BY CI.StartTime DESC '
					+ '
			
					'
				)
			END
		ELSE
			BEGIN
				EXEC(
					'INSERT INTO ' + @myBUF_t
					+ ' SELECT '
					+ @ReplaceSelect + ' FROM ' 
					+ @ReplaceFrom + ' WHERE '
					+ @whereSTR + ' '
					+ @optionSTR + ' ORDER BY CI.StartTime DESC '
					+ '
			
					'
				)									
			END		
		SET @TotTemCounter = @@ROWCOUNT
		SET @InsertCount = @InsertCount + @TotTemCounter
		SET @RemCounter = @RemCounter - @TotTemCounter
		IF (@TopCount > 0 AND @RemCounter <= 0)
			BREAK

		SET @myCounter = @myCounter + 1		
	END	
-----------------------------------------------------------------------------	
PRINT 'INSERT INTO ' + @myBUF_t
PRINT ' SELECT '	+ @ReplaceSelect 
PRINT ' FROM ' + @ReplaceFrom 
PRINT ' WHERE '	+ @ReplaceWhere 
PRINT  @optionSTR 
PRINT ' ORDER BY CI.StartTime DESC'
					
	IF(@@ERROR<>0)
	BEGIN

		EXEC('DROP TABLE ' + @myBUF_t)

		SET @sqlSTR = 'SearchResult query failed...'
		RAISERROR(@sqlSTR, 16, 1)

		PRINT 'INSERT INTO ' + @myBUF_t
		PRINT '(' + @insertSTR + ')'
		PRINT 'SELECT'
		PRINT 'TOP '+ CONVERT(VARCHAR, @TopCount)
		PRINT @selectSTR
		PRINT 'FROM'
		PRINT @fromSTR
		PRINT 'WHERE'
		PRINT @whereSTR
		PRINT CONVERT(NVARCHAR(4000), @optionSTR)
		PRINT 'ORDER BY  CI.StartTime DESC '

		RETURN -1
	END

	SET NOCOUNT OFF
	
	SELECT @InsertCount AS InsertCount
	PRINT @InsertCount
END
GO
----------------------------------------------------------------------------------
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_GetCallsFromAllDatabases]'))
	drop proc [dbo].sp_GetCallsFromAllDatabases
GO
CREATE   PROC [dbo].[sp_GetCallsFromAllDatabases]
	@s_Date AS CHAR(8),
	@e_Date AS CHAR(8),
	@OptionSTR AS NVARCHAR(MAX) = ''
AS

BEGIN
	/*Variables defined on 2 Nov 2008*/
	DECLARE @myRecords int
	DECLARE @myCounter int
	DECLARE @myDBName VARCHAR(32)
	DECLARE @mySQLCmdText VARCHAR(4096)
	DECLARE @s_DateTime VARCHAR(16)
	DECLARE @e_DateTime VARCHAR(16)

	SET @s_DateTime=@s_Date + '000000'
	SET @e_DateTime=@e_Date + '235959'

	SET NOCOUNT ON

	/*first of all obtain the databases that contain the records of user selected date & time range*/
	CREATE TABLE  #tempRequiredDatabases (TempRecordIndex INT PRIMARY KEY IDENTITY(0, 1),[TempDatabaseName] [char] (32) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL) 
	INSERT INTO #tempRequiredDatabases(TempDatabaseName) select [db_name] from tbl_Database where last_record_datetime>=@s_DateTime and first_record_datetime<=@e_DateTime order by db_chain_id  asc
	SELECT @myRecords=count(TempRecordIndex) from #tempRequiredDatabases

	if(@myRecords IS NULL OR @myRecords < 1)
	BEGIN
		DROP TABLE #tempRequiredDatabases
		RAISERROR('Invalid Database Operation...', 16, 1)
		RETURN -1
	END

	BEGIN TRY
		IF exists(select  COUNT(*) from tempdb.dbo.sysobjects o where o.xtype in ('U') and o.name = 'tbl_ASLReport')
			BEGIN				
				EXEC('DROP TABLE tbl_ASLReport')
			END
		ELSE IF(object_id('tbl_ASLReport') IS NOT NULL)
			BEGIN
				IF exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[tbl_ASLReport]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
				BEGIN
					drop table [dbo].[tbl_ASLReport]
				END
			END
	END TRY
	BEGIN CATCH
	END CATCH; 
	
	SELECT top 1 * INTO tbl_ASLReport from tbl_Calls where CallID = NULL
	SET @myCounter=0

   	WHILE( @myCounter < @myRecords )
		BEGIN
			SELECT @myDBName=TempDatabaseName from #tempRequiredDatabases where TempRecordIndex=@myCounter
			SET @mySQLCmdText=''
			SET @mySQLCmdText='INSERT INTO tbl_ASLReport '
			SET @mySQLCmdText=@mySQLCmdText + 'select * from [' + @myDBName + '].[dbo].[tbl_Calls] CI ' + char(13)
			IF(@OptionSTR != '')
				BEGIN
					SET @mySQLCmdText=@mySQLCmdText + 'where ' + @OptionSTR + ' AND CI.[Duration] > 0 AND CI.[StartTime] IS NOT NULL AND  CI.[StartTime]>'''  + @s_DateTime + ''''
				END
			ELSE
				BEGIN
					SET @mySQLCmdText=@mySQLCmdText + 'where CI.[Duration] > 0 AND CI.[StartTime] IS NOT NULL AND  CI.[StartTime]>'''  + @s_DateTime + ''''
				END
			SET @mySQLCmdText=@mySQLCmdText + ' and  CI.[StartTime]<'''  + @e_DateTime + ''' order by  CI.[StartTime] asc'
			EXEC(@mySQLCmdText)		
			SET @myCounter = @myCounter + 1
		END	
	SET NOCOUNT OFF
END	
GO

------------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS OFF
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_GetDetailReport]'))
	drop proc [dbo].sp_GetDetailReport
GO
CREATE PROC [dbo].[sp_GetDetailReport]
	@selectKey AS VARCHAR(128),
	@selectDay AS VARCHAR(128),
	@FromDate AS VARCHAR(8),
	@ToDate AS VARCHAR(8),
	@TimeRange AS VARCHAR(256),
	@Duration AS VARCHAR(256),
	@OptionSTR AS TEXT,
	@CallStatusFlag AS TINYINT = 1, -- 0 = ALL CALL, 1 = CRITICAL CALL, 2 = START MARKED CALL
	@LODFlag AS TINYINT = 0, -- 0 = ALL CALL, 1 = LOG ON DEMAND CALL
	@RatingLevel AS TINYINT = 0, -- 0 = ALL CALL, 1-5 = Rating Level
	@CallDirection AS TINYINT = 0, -- 0 = ALL CALL, 1 = INBOUND CALL, 2 = OUTBOUND, 3 = UNKNOWN
	@BookMarkFlag AS TINYINT = 0, -- 0 = ALL CALL, 1 = BOOKMARKED CALL
	@CallAnswered AS TINYINT = 2 -- 2 = ALL CALL, 1 = Answered CALLs, 0 = Unanswered calls
AS
BEGIN 
	DECLARE @whereSTR NVARCHAR(4000)
	DECLARE @PARENTHESIS AS TINYINT = 0
	SET @whereSTR = ''	
	
	IF @CallStatusFlag = 3
			BEGIN
				SET @PARENTHESIS = 1
				SET @whereSTR = @whereSTR +  '( CI.CallStatusFlag > 0 ' + char(13)
			END
		ELSE IF @CallStatusFlag > 0
			BEGIN
				SET @PARENTHESIS = 1
				SET @whereSTR = @whereSTR +  '( CI.CallStatusFlag = '+ CAST ( @CallStatusFlag AS VARCHAR(1) ) + char(13)
			END
		IF @LODFlag > 0
			BEGIN
				IF @PARENTHESIS = 1	
					BEGIN		
						SET @whereSTR = @whereSTR + 'OR' + char(13)
					END
				ELSE
					BEGIN		
						SET @PARENTHESIS = 1
						SET @whereSTR = @whereSTR + '( ' + char(13)
					END				
				SET @whereSTR = @whereSTR +  ' CI.LODFlag = '+ CAST ( @LODFlag AS VARCHAR(1) ) + char(13)
			END		
		IF @BookMarkFlag > 0
			BEGIN
				IF @PARENTHESIS = 1	
					BEGIN		
						SET @whereSTR = @whereSTR + 'OR' + char(13)
					END
				ELSE
					BEGIN		
						SET @PARENTHESIS = 1
						SET @whereSTR = @whereSTR + ' ( ' + char(13)
					END
				SET @whereSTR = @whereSTR +  ' CI.BookMarkFlag = '+ CAST ( @BookMarkFlag AS VARCHAR(1) ) + char(13)
			END	
		
		IF @PARENTHESIS = 1	
			BEGIN		
				SET @whereSTR = @whereSTR + ')' + char(13)
			END
		IF @RatingLevel > 0
			BEGIN
				IF @PARENTHESIS = 1
					BEGIN
						SET @whereSTR = @whereSTR + ' AND ' + char(13)
					END
				
				SET @whereSTR = @whereSTR +  ' CI.CallRating = '+ CAST ( @RatingLevel AS VARCHAR(1) ) + char(13)
				SET @PARENTHESIS = 1
			END	
		IF @CallAnswered < 2
		BEGIN
			IF @PARENTHESIS = 1
				BEGIN
					SET @whereSTR = @whereSTR + ' AND ' + char(13)
				END
			
			SET @whereSTR = @whereSTR +  ' CI.CallAnswered = '+ CAST ( @CallAnswered AS VARCHAR(1) ) + char(13)
			SET @PARENTHESIS = 1
		END
		IF @CallDirection > 0
			BEGIN
				IF @PARENTHESIS = 1
					BEGIN
						SET @whereSTR = @whereSTR + ' AND ' + char(13)
					END
				
				SET @whereSTR = @whereSTR +  ' CI.Direction = '+ CAST ( @CallDirection AS VARCHAR(1) ) + char(13)
				SET @PARENTHESIS = 1
			END	
IF EXISTS(SELECT TABLE_NAME FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'tbl_ASLReport')
	BEGIN
		DECLARE @selectSTR NVARCHAR(4000)
		SET @selectSTR = ''
		SET @selectSTR = @selectSTR + ' SELECT ' + CHAR(13)
		SET @selectSTR = @selectSTR + @selectKey + ' AS [Key],' + CHAR(13)
		SET @selectSTR = @selectSTR +  @selectDay + ' AS [Day],' + CHAR(13)
		SET @selectSTR = @selectSTR + 'CI.CallID, A.UserName, G.GroupName, EI.ExtName AS [ChannelName], EI.Ext, CI.StartTime, CI.Duration' + CHAR(13)
		
		SET @selectSTR = @selectSTR + 'FROM' + CHAR(13)	
		SET @selectSTR = @selectSTR + 'tbl_ASLReport CI' + CHAR(13)
		SET @selectSTR = @selectSTR + 'LEFT JOIN tbl_User A ON CI.UserNum = A.UserNum' + CHAR(13)
		SET @selectSTR = @selectSTR + 'LEFT JOIN tbl_Group G ON CI.GroupNum = G.GroupNum' + CHAR(13)
		SET @selectSTR = @selectSTR + 'LEFT JOIN tbl_channel EI ON CI.Ext = EI.Ext' + CHAR(13)
		
		SET @selectSTR = @selectSTR + 'WHERE' + CHAR(13)
		SET @selectSTR = @selectSTR + @whereSTR + CHAR(13)
			
		IF @PARENTHESIS = 1
			BEGIN
				SET @selectSTR = @selectSTR + 'AND CI.StartTime BETWEEN ''' + @FromDate + '000000'' AND ''' + @ToDate + '235959''' + CHAR(13)
			END
		ELSE		
			BEGIN
				SET @selectSTR = @selectSTR + 'CI.StartTime BETWEEN ''' + @FromDate + '000000'' AND ''' + @ToDate + '235959''' + CHAR(13)
			END
		SET @selectSTR = @selectSTR + @TimeRange + CHAR(13)
		SET @selectSTR = @selectSTR + @Duration + CHAR(13)
		--Issue was @optionSTR when all users were selected. Out of range string.
		--SET @selectSTR = @selectSTR + @OptionSTR + CHAR(13)
		--SET @selectSTR = @selectSTR + 'ORDER BY [Key]' + CHAR(13)
		
		EXEC(@selectSTR + ' ' + @OptionSTR + ' ORDER BY [Key]')
		
	END
END
GO

----------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS OFF
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_GetHourlyReport]'))
	drop proc [dbo].sp_GetHourlyReport
GO
CREATE PROC [dbo].[sp_GetHourlyReport]
	@selectKey AS VARCHAR(128),
	@selectYear AS VARCHAR(128),
	@selectMonth AS VARCHAR(128),
	@selectDay AS VARCHAR(128),
	@FromDate AS VARCHAR(8),
	@ToDate AS VARCHAR(8),
	@TimeRange AS VARCHAR(256),
	@Duration AS VARCHAR(90),
	@groupKey AS VARCHAR(256),
	@groupYear AS VARCHAR(256),
	@groupMonth AS VARCHAR(256),
	@groupDay AS VARCHAR(256),
	@OptionSTR AS TEXT,--NVARCHAR(MAX),
	@CallStatusFlag AS TINYINT = 1, -- 0 = ALL CALL, 1 = CRITICAL CALL, 2 = START MARKED CALL
	@LODFlag AS TINYINT = 0, -- 0 = ALL CALL, 1 = LOG ON DEMAND CALL
	@RatingLevel AS TINYINT = 0, -- 0 = ALL CALL, 1-5 = Rating Level
	@CallDirection AS TINYINT = 0, -- 0 = ALL CALL, 1 = INBOUND CALL, 2 = OUTBOUND, 3 = UNKNOWN
	@BookMarkFlag AS TINYINT = 0, -- 0 = ALL CALL, 1 = BOOKMARKED CALL
	@CallAnswered AS TINYINT = 2 -- 2 = ALL CALL, 1 = Answered CALLs, 0 = Unanswered calls
	
AS
BEGIN 
	DECLARE @whereSTR NVARCHAR(4000)
	DECLARE @PARENTHESIS AS TINYINT = 0
	
	SET @whereSTR = ''
	
	IF @CallStatusFlag = 3
		BEGIN
			SET @PARENTHESIS = 1
			SET @whereSTR = @whereSTR +  '( CI.CallStatusFlag > 0 ' + char(13)
		END
	ELSE IF @CallStatusFlag > 0
		BEGIN
			SET @PARENTHESIS = 1
			SET @whereSTR = @whereSTR +  '( CI.CallStatusFlag = '+ CAST ( @CallStatusFlag AS VARCHAR(1) ) + char(13)
		END
	IF @LODFlag > 0
		BEGIN
			IF @PARENTHESIS = 1	
				BEGIN		
					SET @whereSTR = @whereSTR + 'OR' + char(13)
				END
			ELSE
				BEGIN		
					SET @PARENTHESIS = 1
					SET @whereSTR = @whereSTR + '( ' + char(13)
				END				
			SET @whereSTR = @whereSTR +  ' CI.LODFlag = '+ CAST ( @LODFlag AS VARCHAR(1) ) + char(13)
		END		
	IF @BookMarkFlag > 0
		BEGIN
			IF @PARENTHESIS = 1	
				BEGIN		
					SET @whereSTR = @whereSTR + 'OR' + char(13)
				END
			ELSE
				BEGIN		
					SET @PARENTHESIS = 1
					SET @whereSTR = @whereSTR + ' ( ' + char(13)
				END
			SET @whereSTR = @whereSTR +  ' CI.BookMarkFlag = '+ CAST ( @BookMarkFlag AS VARCHAR(1) ) + char(13)
		END	
	
	IF @PARENTHESIS = 1	
		BEGIN		
			SET @whereSTR = @whereSTR + ')' + char(13)
		END
	IF @RatingLevel > 0
		BEGIN
			IF @PARENTHESIS = 1
				BEGIN
					SET @whereSTR = @whereSTR + ' AND ' + char(13)
				END
			
			SET @whereSTR = @whereSTR +  ' CI.CallRating = '+ CAST ( @RatingLevel AS VARCHAR(1) ) + char(13)
			SET @PARENTHESIS = 1
		END
	IF @CallAnswered < 2
		BEGIN
			IF @PARENTHESIS = 1
				BEGIN
					SET @whereSTR = @whereSTR + ' AND ' + char(13)
				END
			
			SET @whereSTR = @whereSTR +  ' CI.CallAnswered = '+ CAST ( @CallAnswered AS VARCHAR(1) ) + char(13)
			SET @PARENTHESIS = 1
		END		
	IF @CallDirection > 0
		BEGIN
			IF @PARENTHESIS = 1
				BEGIN
					SET @whereSTR = @whereSTR + ' AND ' + char(13)
				END
			
			SET @whereSTR = @whereSTR +  ' CI.Direction = '+ CAST ( @CallDirection AS VARCHAR(1) ) + char(13)
			SET @PARENTHESIS = 1
		END
		
	EXEC sp_GetCallsFromAllDatabases @FromDate,@ToDate, @whereSTR
	
	IF EXISTS(SELECT TABLE_NAME FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'tbl_ASLReport')
	BEGIN	
		DECLARE @selectSTR NVARCHAR(4000)
		SET @selectSTR = ''
		SET @selectSTR = @selectSTR + ' SELECT ' + CHAR(13)
		SET @selectSTR = @selectSTR + @selectKey + ' AS [Key],' + CHAR(13)
		SET @selectSTR = @selectSTR + @selectYear + ' AS [Year],' + CHAR(13)
		SET @selectSTR = @selectSTR + @selectMonth + ' AS [Month],' + CHAR(13)
		SET @selectSTR = @selectSTR + @selectDay + ' AS [Day],' + CHAR(13)	
		SET @selectSTR = @selectSTR + 'SUBSTRING(CI.StartTime, 9, 2) AS [CallHour],' + CHAR(13)	
		SET @selectSTR = @selectSTR + 'COUNT(CI.CallID) AS [Count],' + CHAR(13)	
		SET @selectSTR = @selectSTR + 'SUM(CAST(CI.Duration AS BIGINT)) AS [Total],' + CHAR(13)
		SET @selectSTR = @selectSTR + 'AVG(CAST(CI.Duration AS BIGINT)) AS [Avg]' + CHAR(13)
		
		SET @selectSTR = @selectSTR + 'FROM' + CHAR(13)	
		SET @selectSTR = @selectSTR + 'tbl_ASLReport CI LEFT JOIN tbl_channel EI ON CI.Ext = EI.Ext' + CHAR(13)
		SET @selectSTR = @selectSTR + 'LEFT JOIN tbl_User A ON CI.UserNum = A.UserNum' + CHAR(13)
		SET @selectSTR = @selectSTR + 'LEFT JOIN tbl_Loggers RI ON CI.RecID = RI.RecID' + CHAR(13)
		SET @selectSTR = @selectSTR + 'LEFT JOIN tbl_Group G ON CI.GroupNum = G.GroupNum' + CHAR(13)
		
		SET @selectSTR = @selectSTR + 'WHERE' + CHAR(13)
		--SET @selectSTR = @selectSTR + @whereSTR + CHAR(13)
		--IF @PARENTHESIS = 1
		--	BEGIN
		--		SET @selectSTR = @selectSTR + 'AND CI.StartTime BETWEEN ''' + @FromDate + '000000'' AND ''' + @ToDate + '235959''' + CHAR(13)
		--	END
		--ELSE		
		--	BEGIN
				SET @selectSTR = @selectSTR + 'CI.StartTime BETWEEN ''' + @FromDate + '000000'' AND ''' + @ToDate + '235959''' + CHAR(13)
			--END
		SET @selectSTR = @selectSTR + @TimeRange + CHAR(13)
		SET @selectSTR = @selectSTR + @Duration + CHAR(13)
		
		--SET @selectSTR = @selectSTR + @OptionSTR + CHAR(13)
		
		DECLARE @GroupBySTR NVARCHAR(4000)
		
		SET @GroupBySTR = CHAR(13) + 'GROUP BY' + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + @groupKey + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + @groupYear + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + @groupMonth + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + @groupDay + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + ',SUBSTRING(CI.StartTime, 9, 2)' + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + 'ORDER BY' + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + '[Key],' + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + '[Year],' + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + '[Month],' + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + '[Day],' + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + '[CallHour]' + CHAR(13)
		
		EXEC(@selectSTR+@OptionSTR+@GroupBySTR)
	END
END
GO
-----------------------------------------------------------------------------------------------------	
USE [ASLogger]
GO
SET ANSI_NULLS OFF
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_GetReport]'))
	drop proc [dbo].sp_GetReport
GO
CREATE PROC [dbo].[sp_GetReport]
	@selectKey AS VARCHAR(128),
	@selectYear AS VARCHAR(128),
	@selectMonth AS VARCHAR(128),
	@selectDay AS VARCHAR(128),
	@FromDate AS VARCHAR(8),
	@ToDate AS VARCHAR(8),
	@TimeRange AS VARCHAR(256),
	@Duration AS VARCHAR(90),
	@groupKey AS VARCHAR(256),
	@groupYear AS VARCHAR(256),
	@groupMonth AS VARCHAR(256),
	@groupDay AS VARCHAR(256),
	@OptionSTR AS TEXT,
	@CallStatusFlag AS TINYINT = 0, -- 0 = ALL CALL, 1 = CRITICAL CALL, 2 = START MARKED CALL
	@LODFlag AS TINYINT = 0, -- 0 = ALL CALL, 1 = LOG ON DEMAND CALL
	@RatingLevel AS TINYINT = 0, -- 0 = ALL CALL, 1-5 = Rating Level
	@CallDirection AS TINYINT = 0, -- 0 = ALL CALL, 1 = INBOUND CALL, 2 = OUTBOUND, 3 = UNKNOWN
	@BookMarkFlag AS TINYINT = 0, -- 0 = ALL CALL, 1 = BOOKMARKED CALL
	@CallAnswered AS TINYINT = 2 -- 2 = ALL CALL, 1 = Answered CALLs, 0 = Unanswered calls
AS
BEGIN 
	DECLARE @whereSTR NVARCHAR(4000)
	DECLARE @PARENTHESIS AS TINYINT = 0
	SET @whereSTR = ''
	IF @CallStatusFlag = 3
		BEGIN
			SET @PARENTHESIS = 1
			SET @whereSTR = @whereSTR +  '( CI.CallStatusFlag > 0 ' + char(13)
		END
	ELSE IF @CallStatusFlag > 0
		BEGIN
			SET @PARENTHESIS = 1
			SET @whereSTR = @whereSTR +  '( CI.CallStatusFlag = '+ CAST ( @CallStatusFlag AS VARCHAR(1) ) + char(13)
		END
	IF @LODFlag > 0
		BEGIN
			IF @PARENTHESIS = 1	
				BEGIN		
					SET @whereSTR = @whereSTR + 'OR' + char(13)
				END
			ELSE
				BEGIN		
					SET @PARENTHESIS = 1
					SET @whereSTR = @whereSTR + '( ' + char(13)
				END				
			SET @whereSTR = @whereSTR +  ' CI.LODFlag = '+ CAST ( @LODFlag AS VARCHAR(1) ) + char(13)
		END		
	IF @BookMarkFlag > 0
		BEGIN
			IF @PARENTHESIS = 1	
				BEGIN		
					SET @whereSTR = @whereSTR + 'OR' + char(13)
				END
			ELSE
				BEGIN		
					SET @PARENTHESIS = 1
					SET @whereSTR = @whereSTR + ' ( ' + char(13)
				END
			SET @whereSTR = @whereSTR +  ' CI.BookMarkFlag = '+ CAST ( @BookMarkFlag AS VARCHAR(1) ) + char(13)
		END	
	
	IF @PARENTHESIS = 1	
		BEGIN		
			SET @whereSTR = @whereSTR + ')' + char(13)
		END
	IF @RatingLevel > 0
		BEGIN
			IF @PARENTHESIS = 1
				BEGIN
					SET @whereSTR = @whereSTR + ' AND ' + char(13)
				END
			
			SET @whereSTR = @whereSTR +  ' CI.CallRating = '+ CAST ( @RatingLevel AS VARCHAR(1) ) + char(13)
			SET @PARENTHESIS = 1
		END
	IF @CallAnswered < 2
		BEGIN
			IF @PARENTHESIS = 1
				BEGIN
					SET @whereSTR = @whereSTR + ' AND ' + char(13)
				END
			
			SET @whereSTR = @whereSTR +  ' CI.CallAnswered = '+ CAST ( @CallAnswered AS VARCHAR(1) ) + char(13)
			SET @PARENTHESIS = 1
		END
	IF @CallDirection > 0
		BEGIN
			IF @PARENTHESIS = 1
				BEGIN
					SET @whereSTR = @whereSTR + ' AND ' + char(13)
				END
			
			SET @whereSTR = @whereSTR +  ' CI.Direction = '+ CAST ( @CallDirection AS VARCHAR(1) ) + char(13)
			SET @PARENTHESIS = 1
		END	
	EXEC sp_GetCallsFromAllDatabases @FromDate,@ToDate, @whereSTR
	
	IF EXISTS(SELECT TABLE_NAME FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'tbl_ASLReport')
	BEGIN
		DECLARE @selectSTR NVARCHAR(4000)
		SET @selectSTR = ''
		SET @selectSTR = @selectSTR + ' SELECT ' + CHAR(13)
		SET @selectSTR = @selectSTR + @selectKey + ' AS [Key],' + CHAR(13)
		SET @selectSTR = @selectSTR + @selectYear + ' AS [Year],' + CHAR(13)
		SET @selectSTR = @selectSTR + @selectMonth + ' AS [Month],' + CHAR(13)
		SET @selectSTR = @selectSTR + @selectDay + ' AS [Day],' + CHAR(13)
		SET @selectSTR = @selectSTR + 'COUNT(CI.CallID) AS [Count],' + CHAR(13)
		SET @selectSTR = @selectSTR + 'SUM(CAST(CI.Duration AS BIGINT)) AS [Total],' + CHAR(13)
		SET @selectSTR = @selectSTR + 'AVG(CAST(CI.Duration AS BIGINT)) AS [Avg]' + CHAR(13)
		SET @selectSTR = @selectSTR + 'FROM' + CHAR(13)
		SET @selectSTR = @selectSTR + 'tbl_ASLReport CI LEFT JOIN tbl_channel EI ON CI.Ext = EI.Ext' + CHAR(13)
		SET @selectSTR = @selectSTR + 'LEFT JOIN tbl_User A ON CI.UserNum = A.UserNum' + CHAR(13)
		SET @selectSTR = @selectSTR + 'LEFT JOIN tbl_Loggers RI ON CI.RecID = RI.RecID' + CHAR(13)
		SET @selectSTR = @selectSTR + 'LEFT JOIN tbl_Group G ON CI.GroupNum = G.GroupNum' + CHAR(13)
		SET @selectSTR = @selectSTR + 'WHERE' + CHAR(13)
		--SET @selectSTR = @selectSTR + @whereSTR + CHAR(13)		
		--IF @PARENTHESIS = 1
		--	BEGIN
		--		SET @selectSTR = @selectSTR + 'AND CI.StartTime BETWEEN ''' + @FromDate + '000000'' AND ''' + @ToDate + '235959''' + CHAR(13)
		--	END
		--ELSE		
		--	BEGIN
				SET @selectSTR = @selectSTR + 'CI.StartTime BETWEEN ''' + @FromDate + '000000'' AND ''' + @ToDate + '235959''' + CHAR(13)
			--END
		SET @selectSTR = @selectSTR + @TimeRange + CHAR(13)
		SET @selectSTR = @selectSTR + @Duration + CHAR(13)
		
		--Issue was @optionSTR when all users were selected. Out of range string.
		--SET @selectSTR = @selectSTR + @OptionSTR + CHAR(13)
		DECLARE @GroupBySTR NVARCHAR(4000)		
		SET @GroupBySTR = CHAR(13) + 'GROUP BY' + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + @groupKey + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + @groupYear + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + @groupMonth + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + @groupDay + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + 'ORDER BY' + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + '[Key],' + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + '[Year],' + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + '[Month],' + CHAR(13)
		SET @GroupBySTR = @GroupBySTR + '[Day]' + CHAR(13)	
		EXEC(@selectSTR + @OptionSTR + @GroupBySTR)
	END
END
GO
-----------------------------------------------------------------------------------------------------------------------------------------
USE ASLogger
GO
IF NOT EXISTS(SELECT TABLE_NAME FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'tbl_Survey')
	BEGIN
		CREATE TABLE [dbo].[tbl_Survey](
			[ID] [int] IDENTITY(1,1) NOT NULL,
			[Title] [nvarchar](200) NOT NULL,
			[Description] [nvarchar](500) NULL,
			[CreatedOn] [datetime] NULL,
			[StartOn] [datetime] NULL,
			[ExpireOn] [datetime] NULL,
			[CreatedBy] [int] NOT NULL,
			[Publish] [bit] NULL,
			[IsShared] [bit] NULL,
			[IsActiveOnExpiry] [bit] NULL,
		 CONSTRAINT [PK_tbl_Survey] PRIMARY KEY CLUSTERED 
		(
			[ID] ASC
		)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
		) ON [PRIMARY]
		ALTER TABLE [dbo].[tbl_Survey] ADD  CONSTRAINT [DF_tbl_Survey_Publish]  DEFAULT ((0)) FOR [Publish]
		ALTER TABLE [dbo].[tbl_Survey] ADD  CONSTRAINT [DF_tbl_Survey_IsShared]  DEFAULT ((0)) FOR [IsShared]
		ALTER TABLE [dbo].[tbl_Survey] ADD  CONSTRAINT [DF_tbl_Survey_IsActiveOnExpiry]  DEFAULT ((0)) FOR [IsActiveOnExpiry]
	END
GO
-----------------------------------------------------------------------------------------------------------------------------------------
USE ASLogger
GO
IF NOT EXISTS(SELECT TABLE_NAME FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'tbl_Questions')
	BEGIN
		CREATE TABLE [dbo].[tbl_Questions](
			[ID] [bigint] IDENTITY(1,1) NOT NULL,
			[Question] [nvarchar](1000) NOT NULL,
			[QuestionType] [tinyint] NOT NULL,
			[bCommentsField] [bit] NULL,
			[QuestionRate] [float] NOT NULL,
			[OptionsCount] [int] NULL,
			[DisplayOrder] [int] NULL,
			[CreatedBy] [int] NOT NULL,
			[SurveyID] [int] NOT NULL,
		 CONSTRAINT [PK_tbl_Questions] PRIMARY KEY CLUSTERED 
		(
			[ID] ASC
		)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
		) ON [PRIMARY]

		EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'1 = Single Selection, 2 = Multiple Choice, 3 = Range Based 4 = Text based, ' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'tbl_Questions', @level2type=N'COLUMN',@level2name=N'QuestionType'
		EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'1=Yes, 0=No' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'tbl_Questions', @level2type=N'COLUMN',@level2name=N'bCommentsField'
		EXEC sys.sp_addextendedproperty @name=N'MS_Description', @value=N'Question Display Order' , @level0type=N'SCHEMA',@level0name=N'dbo', @level1type=N'TABLE',@level1name=N'tbl_Questions', @level2type=N'COLUMN',@level2name=N'DisplayOrder'
		ALTER TABLE [dbo].[tbl_Questions] ADD  CONSTRAINT [DF_tbl_Questions_bCommentsField]  DEFAULT ((0)) FOR [bCommentsField]
		ALTER TABLE [dbo].[tbl_Questions] ADD  CONSTRAINT [DF_Table_1_OrderID]  DEFAULT ((0)) FOR [DisplayOrder]		
	END
GO
-----------------------------------------------------------------------------------------------------------------------------------------
USE ASLogger
GO
IF NOT EXISTS(SELECT TABLE_NAME FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'tbl_Options')
	BEGIN
		CREATE TABLE [dbo].[tbl_Options](
			[ID] [bigint] IDENTITY(1,1) NOT NULL,
			[OptionText] [nvarchar](500) NOT NULL,
			[OptionRate] [float] NULL,
			[QuestionID] [bigint] NOT NULL,
		 CONSTRAINT [PK_tbl_Options] PRIMARY KEY CLUSTERED 
		(
			[ID] ASC
		)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
		) ON [PRIMARY]

		ALTER TABLE [dbo].[tbl_Options] ADD  CONSTRAINT [DF_tbl_Options_OptionRate]  DEFAULT ((0)) FOR [OptionRate]
	END
GO
-----------------------------------------------------------------------------------------------------------------------------------------
USE ASLogger
GO
IF NOT EXISTS(SELECT TABLE_NAME FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'tbl_Evaluations')
	BEGIN
		CREATE TABLE [dbo].[tbl_Evaluations](
			[ID] [bigint] IDENTITY(1,1) NOT NULL,
			[CallID] [nchar](64) NOT NULL,
			[IsShared] [bit] NULL,
			[IsEvaluated] [bit] NULL,
			[SurveyID] [int] NULL,
			[UserNum] [int] NOT NULL,
			[StartDate] [datetime] NULL,
			[EndDate] [datetime] NULL,
		 CONSTRAINT [PK_tbl_Evaluations] PRIMARY KEY CLUSTERED 
		(
			[ID] ASC
		)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
		) ON [PRIMARY]
		ALTER TABLE [dbo].[tbl_Evaluations] ADD  CONSTRAINT [DF_tbl_Evaluations_IsShared]  DEFAULT ((0)) FOR [IsShared]
		ALTER TABLE [dbo].[tbl_Evaluations] ADD  CONSTRAINT [DF_Table_1_EvalCompleted]  DEFAULT ((0)) FOR [IsEvaluated]
		ALTER TABLE [dbo].[tbl_Evaluations] ADD  CONSTRAINT [DF_tbl_Evaluations_SurveyID]  DEFAULT ((0)) FOR [SurveyID]
	END
GO
-----------------------------------------------------------------------------------------------------------------------------------------
USE ASLogger
GO
IF NOT EXISTS(SELECT TABLE_NAME FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'tbl_Comments')
	BEGIN
		CREATE TABLE [dbo].[tbl_Comments](
			[ID] [bigint] IDENTITY(1,1) NOT NULL,
			[Comments] [nvarchar](500) NULL,
			[EvalutionID] [bigint] NOT NULL,
			[CommentedBy] [bigint] NOT NULL,
			[QuestionID] [bigint] NOT NULL,
		 CONSTRAINT [PK_tbl_Comments] PRIMARY KEY CLUSTERED 
		(
			[ID] ASC
		)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
		) ON [PRIMARY]
	END
GO
-----------------------------------------------------------------------------------------------------------------------------------------
USE ASLogger
GO
IF NOT EXISTS(SELECT TABLE_NAME FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'tbl_Answers')
	BEGIN
		CREATE TABLE [dbo].[tbl_Answers](
			[ID] [bigint] IDENTITY(1,1) NOT NULL,
			[OptionID] [bigint] NOT NULL,
			[EvalutionID] [bigint] NOT NULL,
			[AnsweredBy] [int] NOT NULL,
			[QuestionID] [bigint] NOT NULL,
		 CONSTRAINT [PK_tbl_Answers] PRIMARY KEY CLUSTERED 
		(
			[ID] ASC
		)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
		) ON [PRIMARY]
	END
GO
-----------------------------------------------------------------------------------------------------------------------------------------
USE ASLogger
GO
IF NOT EXISTS(SELECT TABLE_NAME FROM INFORMATION_SCHEMA.TABLES WHERE TABLE_NAME = 'tbl_AnswerRange')
	BEGIN
		CREATE TABLE [dbo].[tbl_AnswerRange](
			[ID] [bigint] IDENTITY(1,1) NOT NULL,
			[Answer] [int] NOT NULL,
			[EvalutionID] [bigint] NOT NULL,
			[AnsweredBy] [int] NOT NULL,
			[QuestionID] [bigint] NOT NULL,
		 CONSTRAINT [PK_tbl_AnswerRange] PRIMARY KEY CLUSTERED 
		(
			[ID] ASC
		)WITH (PAD_INDEX  = OFF, STATISTICS_NORECOMPUTE  = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS  = ON, ALLOW_PAGE_LOCKS  = ON) ON [PRIMARY]
		) ON [PRIMARY]
END
GO
------------------------------------------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS OFF
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_GetEvaluations]'))
	drop proc [dbo].sp_GetEvaluations
GO
CREATE PROC [dbo].[sp_GetEvaluations]
	@BUF_Name AS VARCHAR(32),
	@s_Date AS CHAR(8) = '',
	@e_Date AS CHAR(8) = '',
	@TopCount AS INT = 100,
	@EvaluationType AS INT = -1, -- -1 = All, 1 = shared, 0 = Unshared
	@SurveyFormId AS INT = 0,
	@AgentId AS INT = 0,
	@EvalStatus AS INT = 0,
	@MinScore  AS INT = 0,
	@MaxScore  AS INT = 0,
	@Evaluator AS INT = 0,
	@optionSTR AS TEXT = ''	
AS
BEGIN

	SET NOCOUNT ON
	
	DECLARE @myBUF_t VARCHAR(256)
	DECLARE @insertSTR NVARCHAR(4000)
	DECLARE @SELECTSTR NVARCHAR(4000)
	DECLARE @FROMSTR NVARCHAR(4000)
	DECLARE @WHERESTR VARCHAR(4000)
	DECLARE @sqlSTR NVARCHAR(4000)
	DECLARE @myRecords int
	DECLARE @myCounter int
	DECLARE @TotTemCounter int
	DECLARE @RemCounter int
	DECLARE @myDBName VARCHAR(32)
	DECLARE @ReplaceInsert VARCHAR(4096)
	DECLARE @ReplaceFROM VARCHAR(4096)
	DECLARE @ReplaceWHERE VARCHAR(4096)
	DECLARE @ReplaceSELECT VARCHAR(4096)
	
	/*first of all obtain the databases that contain the records of user SELECTed date & time range*/
	CREATE TABLE  #tempRequiredDatabases (TempRecordIndex INT PRIMARY KEY IDENTITY(0, 1),[TempDatabaseName] [char] (32) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL)
	 
	INSERT INTO #tempRequiredDatabases(TempDatabaseName) SELECT [db_name] FROM tbl_Database order by db_chain_id  asc
	
	SELECT @myRecords=count(TempRecordIndex) FROM #tempRequiredDatabases

	if(@myRecords IS NULL OR @myRecords < 1)
	BEGIN
		SELECT @myRecords=count(*) FROM tbl_Database
		IF(@myRecords IS NULL OR @myRecords < 1)
			BEGIN
				insert into tbl_Database(db_chain_id,db_name,first_record_datetime,last_record_datetime,db_status,db_created_on_datetime) values(1, 'ASLogger', (SELECT min(StartTime) FROM tbl_Calls), (SELECT max(StartTime) FROM tbl_Calls), 'A', dbo.fn_getDateTimeSTR(GetDate()))
				INSERT INTO #tempRequiredDatabases(TempDatabaseName) SELECT [db_name] FROM tbl_Database order by db_chain_id  asc
				SELECT @myRecords=count(TempRecordIndex) FROM #tempRequiredDatabases
				IF(@myRecords IS NULL OR @myRecords < 1)
				BEGIN 
					DROP TABLE #tempRequiredDatabases
					RETURN 0;
				END
			END
		ELSE
			BEGIN 
				DROP TABLE #tempRequiredDatabases
				RETURN 0;
			END
	END
	
	SET @myBUF_t = @BUF_Name

	DECLARE @SUBSTR VARCHAR(2)
	SET @SUBSTR = LEFT(@myBUF_t, 2) 
	BEGIN TRY
	IF @SUBSTR = '##'
		BEGIN
			If exists(SELECT  COUNT(*) FROM tempdb.dbo.sysobjects o WHERE o.xtype in ('U') AND o.name = @myBUF_t)
			BEGIN
				SET @sqlSTR = 'DROP TABLE ' + @myBUF_t
				EXEC(@sqlSTR)
			END
		END
	ELSE
		BEGIN
			IF(object_id(@myBUF_t) IS NOT NULL)
			BEGIN
				SET @sqlSTR = 'DROP TABLE ' + @myBUF_t
				EXEC(@sqlSTR)
			END
		END
	END TRY
	BEGIN CATCH
	END CATCH; 
	
	SET @sqlSTR = 'CREATE TABLE ' + @myBUF_t + char(13)
	--Call Information tbl_Calls
	SET @sqlSTR = @sqlSTR + '(idx INT PRIMARY KEY IDENTITY(1, 1),' + char(13)
	SET @sqlSTR = @sqlSTR + 'CallIDIDX CHAR(32),' + char(13)	
	SET @sqlSTR = @sqlSTR + 'UserNameIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'GroupNameIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'ExtIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'ExtNameIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'CallTimeIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'CallDurationIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'AudioFileNameIDX VARCHAR(32),' + char(13)
	SET @sqlSTR = @sqlSTR + 'VideoFileNameIDX varchar(100),' + char(13)
	SET @sqlSTR = @sqlSTR + 'StartDayIDX CHAR(8),' + char(13)
	SET @sqlSTR = @sqlSTR + 'StartTimeIDX CHAR(6),' + char(13)
	SET @sqlSTR = @sqlSTR + 'RecorderIPIDX varchar(64),' + char(13)
	SET @sqlSTR = @sqlSTR + 'PlayServerPortIDX int,' + char(13)
	SET @sqlSTR = @sqlSTR + 'RecorderNameIDX nvarchar(64),' + char(13)	
	--Evaluation Information tbl_Evaluations
	SET @sqlSTR = @sqlSTR + 'EVALUATIONIDX BIGINT,' + char(13)
	SET @sqlSTR = @sqlSTR + 'EVALUATORIDX INT,' + char(13)
	SET @sqlSTR = @sqlSTR + 'EVALUATORNAMEIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'EStartDayIDX datetime,' + char(13)
	SET @sqlSTR = @sqlSTR + 'EEndDayIDX datetime,' + char(13)
	SET @sqlSTR = @sqlSTR + 'IsSharedIDX BIT,' + char(13)
	
	--Survery form Information tbl_Survey
	SET @sqlSTR = @sqlSTR + 'SURVEYIDX varchar(100),' + char(13)
	SET @sqlSTR = @sqlSTR + 'SURVEYNAMEIDX varchar(200),' + char(13)
	--Question Information tbl_Questions
	SET @sqlSTR = @sqlSTR + 'QCOUNTIDX INT,' + char(13)
	SET @sqlSTR = @sqlSTR + 'TSCORECOUNTIDX FLOAT,' + char(13)
	--Score Information tbl_Answers	
	SET @sqlSTR = @sqlSTR + 'QANSWERCOUNTIDX FLOAT,' + char(13)
	SET @sqlSTR = @sqlSTR + 'OSCORECOUNTIDX FLOAT' + char(13)	
	
	SET @sqlSTR = @sqlSTR + ')' + char(13)
	EXEC(@sqlSTR)

	EXEC('
		CREATE INDEX IX_' + @myBUF_t + '_StartTime ON ' + @myBUF_t + ' (StartDayIDX DESC, StartTimeIDX DESC) WITH  FILLFACTOR = 80 ON [PRIMARY]
	')

	IF(@@ERROR<>0)
	BEGIN
		SET @sqlSTR = 'SearchResult create failed...' + @sqlSTR
		RAISERROR(@sqlSTR, 16, 1)
		RETURN -1
	END
	--Call Information tbl_Calls
	SET @SELECTSTR = 'CI.CallID AS [CallIDIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'A.UserName AS [UserNameIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'ISNULL(G.GroupName, ''-'') AS [GroupNameIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'ISNULL(CI.Ext, ''-'') AS [ExtIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'ISNULL(EI.ExtName, ''-'') AS [ExtNameIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'dbo.fn_ConvertDate(CI.StartTime) AS [CallTimeIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'dbo.fn_IntToTimeFix(CI.Duration/1000) AS [CallDurationIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'CI.FileName AS [AudioFileNameIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'CI.Screen_Rec_File AS [VideoFileNameIDX],' + char(13)	
	SET @SELECTSTR = @SELECTSTR + 'LEFT(CI.StartTime,8) AS [StartDayIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'RIGHT(CI.StartTime, 6) AS [StartTimeIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'RI.RecIP AS [RecorderIPIDX],' + char(13)
	SET @selectSTR = @selectSTR + 'RI.PlaybackPort AS [PlayServerPortIDX],' + char(13)	
	SET @SELECTSTR = @SELECTSTR + 'RI.RecName AS [RecorderNameIDX],' + char(13)	
	--Evaluation Information tbl_Evaluations	
	SET @SELECTSTR = @SELECTSTR + 'E.ID AS [EVALUATIONIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'E.UserNum AS [EVALUATORIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + '(SELECT UserName FROM tbl_User WHERE UserNum = e.UserNum) AS [EVALUATORNAMEIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'E.StartDate AS [EStartDayIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'E.EndDate AS [EEndDayIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'ISNULL(E.IsShared, ''0'') AS [IsSharedIDX],' + char(13)	
	--Survery form Information tbl_Survey
	SET @SELECTSTR = @SELECTSTR + 'S.ID AS [SURVEYIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'S.Title AS [SURVEYNAMEIDX],' + char(13)
	--Question Information tbl_Questions
	SET @SELECTSTR = @SELECTSTR + 'ISNULL((SELECT count(*) FROM tbl_Questions WHERE SurveyID = E.SurveyID), ''0'') AS [QCOUNTIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'ISNULL((SELECT SUM(QuestionRate) FROM tbl_Questions WHERE SurveyID = E.SurveyID), ''0'') AS [TSCORECOUNTIDX],' + char(13)
	--Score Information tbl_Answers	
	SET @SELECTSTR = @SELECTSTR + 'ISNULL((select COUNT(distinct(a.QuestionID)) 
from tbl_Options o, tbl_Answers a, tbl_questions q 
where a.questionid = q.id and o.id=a.optionid and a.EvalutionID =E.ID), ''0'') AS [QANSWERCOUNTIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'ISNULL((select sum(OptionRate) from tbl_Options o, tbl_Answers a, tbl_questions q where a.questionid = q.id and o.id=a.optionid and a.EvalutionID = E.ID), ''0'') AS [OSCORECOUNTIDX]' + char(13)
	
	SET @FROMSTR = 'tbl_Evaluations E INNER JOIN [#ASLogger#].[dbo].[tbl_Calls] CI ON E.CallID = CI.CallID ' + char(13)
	SET @FROMSTR = @FROMSTR + 'INNER JOIN tbl_Survey S ON S.ID = E.SurveyID' + char(13)
	SET @FROMSTR = @FROMSTR + 'LEFT JOIN tbl_channel EI ON CI.Ext = EI.Ext AND EI.Status = 1' + char(13)		
	SET @FROMSTR = @FROMSTR + 'LEFT JOIN tbl_User A ON CI.UserNum = A.UserNum' + char(13)
	SET @FROMSTR = @FROMSTR + 'LEFT JOIN tbl_Loggers RI ON CI.RecID = RI.RecID  AND RI.Status=1 ' + char(13)
	SET @FROMSTR = @FROMSTR + 'LEFT JOIN tbl_Group G ON CI.GroupNum = G.GroupNum' + char(13)
	
	SET @WHERESTR =  ' WHERE ISNULL(E.IsEvaluated, ''0'') =  ' + CONVERT(VARCHAR(3), @EvalStatus) + char(13)
	
	IF (@Evaluator > 0)
		BEGIN
			SET @sqlSTR = @sqlSTR + ' AND (E.IsShared = 1 OR E.UserNum='+ CONVERT(VARCHAR(10), @Evaluator) + ')'+ char(13)
		END
			
	IF (@EvaluationType > -1)
		BEGIN
			SET @WHERESTR = @WHERESTR + ' AND E.IsShared = ' + CONVERT(VARCHAR(10), @EvaluationType) + char(13)
		END
	
	IF (@SurveyFormId > 0)
		BEGIN
			SET @WHERESTR = @WHERESTR + ' AND E.SurveyID = ' + CONVERT(VARCHAR(10), @SurveyFormId) + char(13)		
		END
		
	IF (@s_Date <> '')
		BEGIN
			SET @WHERESTR = @WHERESTR + ' AND CONVERT (INT, LEFT(REPLACE(CONVERT(VARCHAR(10),E.StartDate,20), ''-'', ''''), 8)) >= ' + @s_Date + char(13)
		END
	
	IF (@e_Date <> '')
		BEGIN
			SET @WHERESTR = @WHERESTR + ' AND CONVERT (INT, LEFT(REPLACE(CONVERT(VARCHAR(10),E.EndDate,20), ''-'', ''''), 8)) <= ' + @e_Date + char(13)
		END
	
	--IF (@AgentId > 0)
	--	BEGIN
	--		SET @WHERESTR = @WHERESTR + ' AND A.UserNum = ' + CONVERT(VARCHAR(10), @AgentId) + char(13)
	--	END
	
	IF (@MinScore > 0)
		BEGIN
			SET @WHERESTR = @WHERESTR +' AND ISNULL((select sum(OptionRate) from tbl_Options o, tbl_Answers a, tbl_questions q where a.questionid = q.id and o.id=a.optionid and a.EvalutionID = E.ID), ''0'') >= ' + CONVERT(VARCHAR(10), @MinScore) + char(13)
		END
	
	IF (@MaxScore > 0)
		BEGIN
			SET @WHERESTR = @WHERESTR +' AND ISNULL((select sum(OptionRate) from tbl_Options o, tbl_Answers a, tbl_questions q where a.questionid = q.id and o.id=a.optionid and a.EvalutionID = E.ID), ''0'') <= ' + CONVERT(VARCHAR(10), @MaxScore) + char(13)
		END
		
	/*IF CONVERT(VARCHAR(256), @optionSTR) <> ''	
		BEGIN
			SET @WHERESTR = @WHERESTR + CONVERT(VARCHAR(4000), @optionSTR) + char(13)
		END
	*/	
	SET @myCounter=0
	SET @TotTemCounter = 0
	set @RemCounter = @TopCount
	
	DECLARE @InsertCount INT
	SET @InsertCount = 0
	WHILE( @myCounter < @myRecords )					
	BEGIN
		
		SELECT @myDBName=TempDatabaseName FROM #tempRequiredDatabases WHERE TempRecordIndex=@myCounter
		SET @ReplaceFROM =  REPLACE(@FROMSTR, '#ASLogger#', LTRIM(RTRIM(@myDBName)))
		SET @ReplaceWHERE =  REPLACE(@WHERESTR, '#ASLogger#', LTRIM(RTRIM(@myDBName)))
		SET @ReplaceSELECT =  REPLACE(@SELECTSTR, '#ASLogger#', LTRIM(RTRIM(@myDBName)))
		
		IF(@TopCount  > 0)
			BEGIN		
				EXEC(
					'INSERT INTO ' + @myBUF_t
					+ ' SELECT TOP '+ @RemCounter + ' ' 
					+ @ReplaceSELECT + ' FROM ' 
					+ @ReplaceFROM 
					+ @ReplaceWHERE + ' ' + 
					@optionSTR + ' ORDER BY CI.StartTime DESC '
					+ '
			
					'
				)
			END
		ELSE
			BEGIN
				EXEC(
					'INSERT INTO ' + @myBUF_t
					+ ' SELECT '
					+ @ReplaceSELECT + ' FROM ' 
					+ @ReplaceFROM + ' WHERE '
					+ @WHERESTR + ' '
					+ @optionSTR + ' ORDER BY CI.StartTime DESC '
					+ '
			
					'
				)									
			END		
		SET @TotTemCounter = @@ROWCOUNT
		SET @InsertCount = @InsertCount + @TotTemCounter
		SET @RemCounter = @RemCounter - @TotTemCounter
		IF (@TopCount > 0 AND @RemCounter <= 0)
			BREAK

		SET @myCounter = @myCounter + 1		
	END	
-----------------------------------------------------------------------------	
--PRINT 'INSERT INTO ' + @myBUF_t
--PRINT ' SELECT '	+ @ReplaceSELECT 
--PRINT ' FROM ' + @ReplaceFROM 
--PRINT  @ReplaceWHERE 
--PRINT  @optionSTR 
PRINT ' ORDER BY CI.StartTime DESC'
					
	IF(@@ERROR<>0)
	BEGIN

		EXEC('DROP TABLE ' + @myBUF_t)

		SET @sqlSTR = 'SearchResult query failed...'
		RAISERROR(@sqlSTR, 16, 1)

		PRINT 'INSERT INTO ' + @myBUF_t
		PRINT '(' + @insertSTR + ')'
		PRINT 'SELECT'
		PRINT 'TOP '+ CONVERT(VARCHAR, @TopCount)
		PRINT @SELECTSTR
		PRINT 'FROM'
		PRINT @FROMSTR
		PRINT 'WHERE'
		PRINT @WHERESTR
		PRINT CONVERT(NVARCHAR(4000), @optionSTR)
		PRINT 'ORDER BY  E.StartDate DESC '

		RETURN -1
	END

	SET NOCOUNT OFF
	
	SELECT @InsertCount AS InsertCount
END
GO
------------------------------------------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS OFF
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_GetEvalReport]'))
	drop proc [dbo].sp_GetEvalReport
GO
CREATE PROC [dbo].[sp_GetEvalReport]
	@BUF_Name AS VARCHAR(32),
	@s_Date AS CHAR(8) = '',
	@e_Date AS CHAR(8) = '',
	@EvaluationType AS INT = -1, -- -1 = All, 1 = shared, 0 = Unshared
	@SurveyFormId AS INT = 0,
	@MinScore  AS INT = 0,
	@MaxScore  AS INT = 0,
	@Evaluator AS INT = 0,
	@optionSTR AS TEXT = ''	
AS
BEGIN

	SET NOCOUNT ON
	
	DECLARE @myBUF_t VARCHAR(256)
	DECLARE @insertSTR VARCHAR(4000)
	DECLARE @SELECTSTR VARCHAR(4000)
	DECLARE @FROMSTR VARCHAR(4000)
	DECLARE @WHERESTR VARCHAR(4000)
	DECLARE @sqlSTR VARCHAR(4000)
	DECLARE @myRecords int
	DECLARE @myCounter int
	DECLARE @TotTemCounter int
	DECLARE @RemCounter int
	DECLARE @myDBName VARCHAR(32)
	DECLARE @ReplaceInsert VARCHAR(4096)
	DECLARE @ReplaceFROM VARCHAR(4096)
	DECLARE @ReplaceWHERE VARCHAR(4096)
	DECLARE @ReplaceSELECT VARCHAR(4096)
	
	/*first of all obtain the databases that contain the records of user SELECTed date & time range*/
	CREATE TABLE  #tempRequiredDatabases (TempRecordIndex INT PRIMARY KEY IDENTITY(0, 1),[TempDatabaseName] [char] (32) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL)
	 
	INSERT INTO #tempRequiredDatabases(TempDatabaseName) SELECT [db_name] FROM tbl_Database order by db_chain_id  asc
	
	SELECT @myRecords=count(TempRecordIndex) FROM #tempRequiredDatabases

	if(@myRecords IS NULL OR @myRecords < 1)
	BEGIN
		SELECT @myRecords=count(*) FROM tbl_Database
		IF(@myRecords IS NULL OR @myRecords < 1)
			BEGIN
				insert into tbl_Database(db_chain_id,db_name,first_record_datetime,last_record_datetime,db_status,db_created_on_datetime) values(1, 'ASLogger', (SELECT min(StartTime) FROM tbl_Calls), (SELECT max(StartTime) FROM tbl_Calls), 'A', dbo.fn_getDateTimeSTR(GetDate()))
				INSERT INTO #tempRequiredDatabases(TempDatabaseName) SELECT [db_name] FROM tbl_Database order by db_chain_id  asc
				SELECT @myRecords=count(TempRecordIndex) FROM #tempRequiredDatabases
				IF(@myRecords IS NULL OR @myRecords < 1)
				BEGIN 
					DROP TABLE #tempRequiredDatabases
					RETURN 0;
				END
			END
		ELSE
			BEGIN 
				DROP TABLE #tempRequiredDatabases
				RETURN 0;
			END
	END
	
	SET @myBUF_t = @BUF_Name

	DECLARE @SUBSTR VARCHAR(2)
	SET @SUBSTR = LEFT(@myBUF_t, 2) 
	BEGIN TRY
	IF @SUBSTR = '##'
		BEGIN
			If exists(SELECT  COUNT(*) FROM tempdb.dbo.sysobjects o WHERE o.xtype in ('U') AND o.name = @myBUF_t)
			BEGIN
				SET @sqlSTR = 'DROP TABLE ' + @myBUF_t
				EXEC(@sqlSTR)
			END
		END
	ELSE
		BEGIN
			IF(object_id(@myBUF_t) IS NOT NULL)
			BEGIN
				SET @sqlSTR = 'DROP TABLE ' + @myBUF_t
				EXEC(@sqlSTR)
			END
		END
	END TRY
	BEGIN CATCH
	END CATCH; 

	IF(object_id('QDetial') IS NOT NULL)
	BEGIN
		SET @sqlSTR = 'DROP TABLE QDetial'
		EXEC(@sqlSTR)
	END
	
	SET @sqlSTR = 'SELECT E.ID EvalId, E.CallID, E.UserNum, E.EndDate, E.IsShared, q.QuestionRate QScore, ' + char(13)
	SET @sqlSTR = @sqlSTR + '(' + char(13)
	SET @sqlSTR = @sqlSTR + 'SELECT sum(oo.OptionRate)' + char(13)
	SET @sqlSTR = @sqlSTR + 'FROM tbl_Options oo, tbl_Answers aa ' + char(13)
	SET @sqlSTR = @sqlSTR + 'WHERE aa.EvalutionID = e.id AND aa.questionid = q.id AND oo.id=aa.optionid' + char(13)
	SET @sqlSTR = @sqlSTR + ') QOScore, q.id, q.question into QDetial' + char(13)
	SET @sqlSTR = @sqlSTR + 'FROM tbl_questions q, tbl_Evaluations E' + char(13)
	SET @sqlSTR = @sqlSTR + 'WHERE E.SurveyID = ' + CONVERT(VARCHAR(10), @SurveyFormId) + ' AND E.IsEvaluated = 1' + char(13)
	
	IF (@Evaluator > 0)
		BEGIN
			SET @sqlSTR = @sqlSTR + ' AND (E.IsShared = 1 OR E.UserNum='+ CONVERT(VARCHAR(10), @Evaluator) + ')'+ char(13)
		END
	IF (@EvaluationType > -1)
		BEGIN
			SET @sqlSTR = @sqlSTR + ' AND E.IsShared = ' + CONVERT(VARCHAR(10), @EvaluationType) + char(13)
		END
		
	IF (@s_Date <> '')
		BEGIN
			SET @sqlSTR = @sqlSTR + ' AND CONVERT (INT, LEFT(REPLACE(CONVERT(VARCHAR(10),E.EndDate,20), ''-'', ''''), 8)) >= ' + @s_Date + char(13)
		END
	
	IF (@e_Date <> '')
		BEGIN
			SET @sqlSTR = @sqlSTR + ' AND CONVERT (INT, LEFT(REPLACE(CONVERT(VARCHAR(10),E.EndDate,20), ''-'', ''''), 8)) <= ' + @e_Date + char(13)
		END
	
	IF (@MinScore > 0)
		BEGIN
			SET @sqlSTR = @sqlSTR +' AND ISNULL((SELECT sum(OptionRate) FROM tbl_Options o, tbl_Answers a, tbl_questions q WHERE a.questionid = q.id and o.id=a.optionid and a.EvalutionID = E.ID), ''0'') >= ' + CONVERT(VARCHAR(10), @MinScore) + char(13)
		END
	
	IF (@MaxScore > 0)
		BEGIN
			SET @sqlSTR = @sqlSTR +' AND ISNULL((SELECT sum(OptionRate) FROM tbl_Options o, tbl_Answers a, tbl_questions q WHERE a.questionid = q.id and o.id=a.optionid and a.EvalutionID = E.ID), ''0'') <= ' + CONVERT(VARCHAR(10), @MaxScore) + char(13)
		END
		
	SET @sqlSTR = @sqlSTR + 'AND E.SurveyID=q.SurveyID order  by E.ID' + char(13)
	
	EXEC(@sqlSTR)
	
	
	IF(@@ERROR<>0)
		BEGIN
			SET @sqlSTR = 'Report creation failed...' + @sqlSTR
			RAISERROR(@sqlSTR, 16, 1)
			RETURN -1
		END
		
	SET @sqlSTR = 'CREATE TABLE ' + @myBUF_t + char(13)
	--Call Information tbl_Calls
	SET @sqlSTR = @sqlSTR + '(idx INT PRIMARY KEY IDENTITY(1, 1),' + char(13)
	SET @sqlSTR = @sqlSTR + 'UserNameIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'GroupNameIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'ExtIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'ExtNameIDX nvarchar(256),' + char(13)
	--Evaluation Information tbl_Evaluations	
	SET @sqlSTR = @sqlSTR + 'EVALUATORNAMEIDX nvarchar(256),' + char(13)
	SET @sqlSTR = @sqlSTR + 'EVALUATIONIDX BIGINT,' + char(13)
	SET @sqlSTR = @sqlSTR + 'EEndDayIDX datetime,' + char(13)
	SET @sqlSTR = @sqlSTR + 'IsSharedIDX BIT,' + char(13)
	--Question Information tbl_Questions
	SET @sqlSTR = @sqlSTR + 'QScoreIDX FLOAT,' + char(13)
	SET @sqlSTR = @sqlSTR + 'QOScoreIDX FLOAT,' + char(13)
	SET @sqlSTR = @sqlSTR + 'QIDIDX BIGINT,' + char(13)
	SET @sqlSTR = @sqlSTR + 'QuestionIDX VARCHAR(500)' + char(13)	
	
	SET @sqlSTR = @sqlSTR + ')' + char(13)
	EXEC(@sqlSTR)

	EXEC('
		CREATE INDEX IX_' + @myBUF_t + '_StartTime ON ' + @myBUF_t + ' (EEndDayIDX DESC) WITH  FILLFACTOR = 80 ON [PRIMARY]
	')

	IF(@@ERROR<>0)
	BEGIN
		SET @sqlSTR = 'SearchResult create failed...' + @sqlSTR
		RAISERROR(@sqlSTR, 16, 1)
		RETURN -1
	END
	
	
	SET @SELECTSTR = 'SELECT A.UserName AS [UserNameIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'ISNULL(G.GroupName, ''-'') AS [GroupNameIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'ISNULL(CI.Ext, ''-'') AS [ExtIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'ISNULL(EI.ExtName, ''-'') AS [ExtNameIDX],' + char(13)
	SET @SELECTSTR = @SELECTSTR + '(SELECT UserName FROM tbl_User WHERE UserNum = q.UserNum) AS [EVALUATORNAMEIDX], ' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'q.EvalId AS EVALUATIONIDX, q.EndDate AS EEndDayIDX, q.IsShared AS IsSharedIDX, q.QScore AS QScoreIDX, q.QOScore AS QOScoreIDX, q.id AS QIDIDX, q.question AS QuestionIDX' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'FROM QDetial q,  [#ASLogger#].[dbo].[tbl_Calls] CI, tbl_User A, tbl_Group G, tbl_channel EI' + char(13)
	SET @SELECTSTR = @SELECTSTR + 'WHERE q.CallID = CI.CallID AND A.usernum = CI.usernum AND CI.GroupNum = G.GroupNum AND CI.Ext = EI.Ext ' + char(13)
	
	DECLARE @InsertCount INT
	SET @InsertCount = 0
	SET @myCounter = 0
	PRINT @myRecords
	WHILE( @myCounter < @myRecords )					
	BEGIN		
		SELECT @myDBName=TempDatabaseName FROM #tempRequiredDatabases WHERE TempRecordIndex=@myCounter
		SET @ReplaceSELECT =  REPLACE(@SELECTSTR, '#ASLogger#', LTRIM(RTRIM(@myDBName)))
		EXEC('INSERT INTO '+ @myBUF_t + ' ' + @ReplaceSELECT + @optionSTR + ' order  by q.EvalId, q.EndDate DESC')		
		SET @InsertCount = @InsertCount + @@ROWCOUNT		
		SET @myCounter = @myCounter +1
	END	
	
	IF(object_id('QDetial') IS NOT NULL)
		BEGIN
			SET @sqlSTR = 'DROP TABLE QDetial'
			EXEC(@sqlSTR)
		END
	
	IF(@@ERROR<>0)
		BEGIN
			SET @sqlSTR = 'SearchResult query failed...'
			RAISERROR(@sqlSTR, 16, 1)
			PRINT @SELECTSTR
			RETURN -1
		END

	SET NOCOUNT OFF
	--SELECT @InsertCount AS InsertCount
	SET @sqlSTR = 'select * from ' + @myBUF_t + ' order by EEndDayIdx'
	EXEC(@sqlSTR)
END
GO
------------------------------------------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS OFF
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_CreateSurveyList]'))
	drop proc [dbo].sp_CreateSurveyList
GO
CREATE PROC [dbo].[sp_CreateSurveyList]
	@BUF_Name AS VARCHAR(32)
AS	
	BEGIN
		DECLARE @sqlSTR NVARCHAR(4000)
		DECLARE @SUBSTR VARCHAR(2)
		SET @SUBSTR = LEFT(@BUF_Name, 2) 
		BEGIN TRY
			IF @SUBSTR = '##'
				BEGIN
					If exists(select  COUNT(*) from tempdb.dbo.sysobjects o where o.xtype in ('U') and o.name = @BUF_Name)
					BEGIN
						SET @sqlSTR = 'DROP TABLE ' + @BUF_Name
						EXEC(@sqlSTR)
					END
				END
			ELSE
				BEGIN
					IF(object_id(@BUF_Name) IS NOT NULL)
					BEGIN
						SET @sqlSTR = 'DROP TABLE ' + @BUF_Name
						EXEC(@sqlSTR)
					END
				END
		END TRY
		BEGIN CATCH
		END CATCH; 
			
		SET @sqlSTR = 'SELECT * INTO ' + @BUF_Name + ' from ' +char(13)
		SET @sqlSTR = @sqlSTR + '(SELECT ROW_NUMBER() OVER (ORDER BY S.ID) AS [ROWID], S.ID AS [IDX],	S.TITLE AS [TitleIDX],' +char(13)
		SET @sqlSTR = @sqlSTR + 'ISNULL((SELECT COUNT(*) FROM tbl_Questions where S.ID = SurveyID), 0) QUESTIONIDX,' +char(13)
		SET @sqlSTR = @sqlSTR + 'ISNULL((SELECT SUM(QuestionRate) FROM tbl_Questions where S.ID = SurveyID), 0) ScoreIDX,' +char(13)
		SET @sqlSTR = @sqlSTR + 'S.StartOn AS [StartOnIDX],' +char(13)
		SET @sqlSTR = @sqlSTR + 'S.ExpireOn AS [ExpireOnIDX],' +char(13)
		SET @sqlSTR = @sqlSTR + 'S.Publish AS [PublishIDX]' +char(13)
		SET @sqlSTR = @sqlSTR + 'FROM tbl_Survey S) AS LIST' +char(13)
		EXEC(@sqlSTR)
		SET @sqlSTR = 'SELECT COUNT(*) FROM ' + @BUF_Name + char(13)
		EXEC(@sqlSTR)		
	END
GO
------------------------------------------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS OFF
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_SurveyList]'))
	drop proc [dbo].sp_SurveyList
GO
CREATE PROC [dbo].[sp_SurveyList]	
	@TopCount AS INT = 100,
	@SORTINDEX AS NVARCHAR(50),
	@PageNum AS INT
AS
	
	BEGIN
		DECLARE @sqlSTR NVARCHAR(4000)
		
		SELECT COUNT(*) FROM tbl_Survey
			
		SET @sqlSTR = 'SELECT TOP ' + @TopCount + ' S.ID AS [IDX],' + char(13)
		SET @sqlSTR = @sqlSTR + 'S.TITLE AS [TitleIDX],' + char(13)
		SET @sqlSTR = @sqlSTR + '(SELECT COUNT(*) FROM tbl_Questions where S.ID = SurveyID) QUESTIONIDX,' + char(13)
		SET @sqlSTR = @sqlSTR + '(SELECT SUM(QuestionRate) FROM tbl_Questions where S.ID = SurveyID) ScoreIDX,' + char(13)
		SET @sqlSTR = @sqlSTR + 'S.CreatedOn AS [StartOnIDX],' + char(13)
		SET @sqlSTR = @sqlSTR + 'S.ExpireOn AS [ExpireOnIDX],' + char(13)
		SET @sqlSTR = @sqlSTR + 'S.Publish AS [PublishIDX]' + char(13)
		SET @sqlSTR = @sqlSTR + 'FROM tbl_Survey S LEFT JOIN tbl_Questions Q ON S.ID = Q.SurveyID' + char(13)
		SET @sqlSTR = @sqlSTR + 'ORDER BY ' + @SORTINDEX + char(13)
	END
GO
------------------------------------------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
/****** Object:  StoredProcedure [dbo].[sp_GetUsers]    Script Date: 08/30/2013 10:34:18 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER OFF
GO
ALTER PROC [dbo].[sp_GetUsers]
	@UserNum AS INT = 0,
	@AuthNum AS INT,
	@AuthType AS CHAR(1) = '1',
	@Type AS INT = 2
AS
BEGIN

	SET NOCOUNT ON
	
	DECLARE @UserType INT
	
	Select @UserType = UserType from tbl_User where UserNum = @UserNum
	IF (@UserType = 0)
		BEGIN
			EXEC sp_GetNormalUsers @UserNum,@AuthNum ,@AuthType ,@Type
			RETURN
		END
		
	DECLARE @FromIndexNum INT
	DECLARE @ToIndexNum INT
	DECLARE @tm_GroupNum INT
	DECLARE @tm_Depth INT
	DECLARE @tm_ParentGroup INT
	DECLARE @tm_MonitorPage INT
	
	Set @tm_MonitorPage = 0
	
	
	CREATE TABLE #tm_Tree(
		GroupID VARCHAR(32) PRIMARY KEY,
		NodeCaption NVARCHAR(64),
		ParentGroupID VARCHAR(32),
		Depth INT,
		MenuType INT,
		ViewType INT,
		IsGroup INT,
		Param1 NVARCHAR(64),
		Param2 NVARCHAR(64),
		Param3 NVARCHAR(64)
	)
	--Radio Talk Group
	IF(@Type = 6)
	BEGIN
		INSERT INTO #tm_Tree select ID as GroupID, TalkGroup as NodeCaption, 1000 as ParentGroupID, 1 as Depth, 1 as MenuType, 1 as ViewType, 0 as IsGroup, ID as Param1, TalkGroup as param2, 1 as param3 from tbl_RadioTalkGroup
		INSERT INTO #tm_Tree(GroupID, NodeCaption, ParentGroupID,Depth, MenuType, ViewType, IsGroup, Param1, param2, param3)
		values(1000, 'Radio Talk Groups', 1000, 0,1,0,1,1000,1, 1)
		SELECT * FROM #tm_Tree ORDER BY ViewType, right('00000000000000000000000000000000'+NodeCaption, 32)
		SET NOCOUNT ON
		DROP TABLE #tm_Tree
		SET NOCOUNT OFF
		RETURN
	END
	--End Radio Talk Group
	CREATE TABLE #tm_MyGroup(
		GroupNum INT PRIMARY KEY,
		ParentGroup INT,
		IndexNum INT,
		Depth INT
	)
	
	INSERT INTO #tm_MyGroup
		SELECT
			G.GroupNum, G.ParentGroup, G.IndexNum, G.Depth
		FROM
			tbl_Group G LEFT JOIN tbl_UserGroup AG ON G.GroupNum = AG.GroupNum AND G.Status = 1
		WHERE
			AG.UserNum = @UserNum AND AG.CreateID = 0 AND SUBSTRING(AG.AssignAuth, @AuthNum, 1) = @AuthType
	SET @FromIndexNum = -1

	WHILE(@FromIndexNum IS NOT NULL)
	BEGIN

		SET @tm_GroupNum = NULL
		SELECT @FromIndexNum = MIN(IndexNum) FROM #tm_MyGroup

		IF(@FromIndexNum IS NOT NULL)
		BEGIN
			SELECT @tm_GroupNum = GroupNum, @tm_Depth = Depth, @tm_ParentGroup = ParentGroup FROM #tm_MyGroup WHERE IndexNum = @FromIndexNum
			SELECT @ToIndexNum = MIN(IndexNum) FROM tbl_Group WHERE Status = 1 AND IndexNum > @FromIndexNum AND Depth <= @tm_Depth

			IF(@ToIndexNum IS NULL)
				SELECT @ToIndexNum = MAX(IndexNum)+1 FROM tbl_Group
			
			INSERT INTO #tm_Tree
				SELECT
					CONVERT(VARCHAR(32), GroupNum), GroupName, CONVERT(VARCHAR(32), ParentGroup), Depth, 1, 0, 1, CONVERT(NVARCHAR(64), GroupNum), '', CONVERT(NVARCHAR(64), IndexNum)
				FROM
					tbl_Group
				WHERE
					Status = 1 AND IndexNum >= @FromIndexNum AND IndexNum < @ToIndexNum

			WHILE (@tm_Depth > 0)
			BEGIN

				INSERT INTO #tm_Tree
					SELECT
						CONVERT(VARCHAR(32), GroupNum), GroupName, CONVERT(VARCHAR(32), ParentGroup), Depth, 0, 0, 1, CONVERT(NVARCHAR(64), GroupNum), '', CONVERT(NVARCHAR(64), IndexNum)
					FROM
						tbl_Group
					WHERE
						GroupNum = @tm_ParentGroup
						AND
						NOT GroupNum IN (SELECT CONVERT(INT, GroupID) FROM #tm_Tree)

				SELECT @tm_ParentGroup = ParentGroup FROM tbl_Group WHERE GroupNum = @tm_ParentGroup
		
				SET @tm_Depth = @tm_Depth - 1
			
			END

			DELETE FROM #tm_MyGroup WHERE IndexNum = @FromIndexNum
		END

	END

	DROP TABLE #tm_MyGroup

	IF(@Type = 0 OR @Type = 2)
	BEGIN
		INSERT INTO #tm_Tree
			SELECT
				CONVERT(VARCHAR, G.GroupNum) + 'A' + CONVERT(VARCHAR, A.UserNum), A.UserName, CONVERT(VARCHAR(32), G.GroupNum), G.Depth+1, 1, 2, 0, CONVERT(NVARCHAR(64), G.GroupNum), CONVERT(NVARCHAR(64), A.UserNum), CONVERT(NVARCHAR(64), G.IndexNum)
			FROM
				tbl_UserGroup AG
					LEFT JOIN  tbl_Group G ON G.GroupNum = AG.GroupNum AND AG.CreateID = 0
					LEFT JOIN tbl_User A ON A.Ext > 0 AND AG.UserNum = A.UserNum AND A.Status = 1
			WHERE
				G.GroupNum IN (SELECT CONVERT(INT, GroupID) FROM #tm_Tree WHERE MenuType = 1 AND IsGroup = 1) AND A.UserNum IS NOT NULL --AND SUBSTRING(A.UserName,1,4)<>'User' 

	END
	IF(@Type = 4)
	BEGIN
		INSERT INTO #tm_Tree
			SELECT
				CONVERT(VARCHAR, G.GroupNum) + 'E' + E.Ext,  E.ExtName, CONVERT(VARCHAR(32), G.GroupNum), G.Depth+1, 1, 1, 0, CONVERT(NVARCHAR(64), G.GroupNum), CONVERT(NVARCHAR(64), E.Ext), CONVERT(NVARCHAR(64), G.IndexNum)
			FROM
				tbl_UserGroup EG
					LEFT JOIN tbl_Group G ON G.GroupNum = EG.GroupNum-- AND EG.CreateID = 0
					LEFT JOIN tbl_channel E ON EG.Ext = E.Ext AND E.Status = 1-- AND EG.ExtName = E.ExtName
			WHERE
				G.GroupNum IN (SELECT CONVERT(INT, GroupID) FROM #tm_Tree WHERE MenuType = 1 AND IsGroup = 1) AND E.Ext IS NOT NULL
	END
	IF(@Type = 3)
	BEGIN
		INSERT INTO #tm_Tree
			SELECT
				CONVERT(VARCHAR, G.GroupNum) + 'A' + CONVERT(VARCHAR, A.UserNum), A.UserName, CONVERT(VARCHAR(32), G.GroupNum), G.Depth+1, 1, 3, 0, CONVERT(NVARCHAR(64), G.GroupNum), CONVERT(NVARCHAR(64), A.UserNum), CONVERT(NVARCHAR(64), G.IndexNum)
			FROM
				tbl_UserGroup AG
					LEFT JOIN  tbl_Group G ON G.GroupNum = AG.GroupNum AND AG.CreateID = 0
					LEFT JOIN tbl_User A ON AG.UserNum = A.UserNum AND A.Status = 0
			WHERE
				G.GroupNum IN (SELECT CONVERT(INT, GroupID) FROM #tm_Tree WHERE MenuType = 1 AND IsGroup = 1) AND A.UserNum IS NOT NULL
	END
	
	IF(@Type = 1 OR @Type = 2)
	BEGIN
		INSERT INTO #tm_Tree
			SELECT
				CONVERT(VARCHAR, G.GroupNum) + 'E' + E.Ext, dbo.GetChannelDisplayName( E.Ext, E.ExtName), CONVERT(VARCHAR(32), G.GroupNum), G.Depth+1, 1, 1, 0, CONVERT(NVARCHAR(64), G.GroupNum), CONVERT(NVARCHAR(64), E.Ext), CONVERT(NVARCHAR(64), G.IndexNum)
			FROM
				tbl_UserGroup EG
					LEFT JOIN tbl_Group G ON G.GroupNum = EG.GroupNum-- AND EG.CreateID = 0
					LEFT JOIN tbl_channel E ON EG.Ext = E.Ext AND E.Status = 1
			WHERE
				G.GroupNum IN (SELECT CONVERT(INT, GroupID) FROM #tm_Tree WHERE MenuType = 1 AND IsGroup = 1) AND E.Ext IS NOT NULL order by dbo.GetChannelDisplayName( E.Ext, E.ExtName)
				
			SET @tm_MonitorPage = 1
	END

	IF(@Type = 5)
	BEGIN
		INSERT INTO #tm_Tree
			SELECT
				CONVERT(VARCHAR, G.GroupNum) + 'A' + CONVERT(VARCHAR, A.UserNum), A.UserName, CONVERT(VARCHAR(32), G.GroupNum), G.Depth+1, 1, 2, 0, CONVERT(NVARCHAR(64), G.GroupNum), CONVERT(NVARCHAR(64), A.UserNum), CONVERT(NVARCHAR(64), G.IndexNum)
			FROM
				tbl_UserGroup AG
					LEFT JOIN  tbl_Group G ON G.GroupNum = AG.GroupNum AND AG.CreateID = 0
					RIGHT JOIN tbl_User A ON A.Ext >= 0 AND AG.UserNum = A.UserNum AND A.Status = 1
			WHERE
				G.GroupNum IN (SELECT CONVERT(INT, GroupID) FROM #tm_Tree WHERE MenuType = 1) AND A.UserNum IS NOT NULL
	END
	SET NOCOUNT OFF
	
	IF(@tm_MonitorPage = 1)
		BEGIN
			IF(@Type = -1)
				BEGIN
					SELECT * FROM #tm_Tree ORDER BY NodeCaption
				END
			ELSE
				BEGIN			
					SELECT distinct t1.* from  #tm_Tree t1
					join (SELECT param1  FROM #tm_Tree WHERE param1 <> '' AND param2 <> '')t2 on t1.param1 = t2.param1 AND 
					t1.param1 = t2.param1
					join (SELECT param1 FROM #tm_Tree WHERE param1 <> '' AND param2 = '') t3 on t2.param1 = t3.param1 AND 
					t1.param1 = t3.param1 ORDER BY t1.NodeCaption
				END
		END
	ELSE
		BEGIN
			IF(@Type = -1)
				BEGIN
					SELECT * FROM #tm_Tree ORDER BY ViewType, right('00000000000000000000000000000000'+NodeCaption, 32)
				END
			ELSE
				BEGIN
					SELECT distinct t1.* from  #tm_Tree t1
					join (SELECT param1  FROM #tm_Tree WHERE param1 <> '' AND param2 <> '')t2 on t1.param1 = t2.param1 AND 
					t1.param1 = t2.param1
					join (SELECT param1 FROM #tm_Tree WHERE param1 <> '' AND param2 = '') t3 on t2.param1 = t3.param1 AND 
					t1.param1 = t3.param1 ORDER BY t1.NodeCaption
				END
		END

	SET NOCOUNT ON

	DROP TABLE #tm_Tree

	SET NOCOUNT OFF

END
GO
------------------------------------------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
/****** Object:  StoredProcedure [dbo].[sp_GetNormalUsers]    Script Date: 01/01/2014 15:17:17 ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER OFF
GO
ALTER PROC [dbo].[sp_GetNormalUsers]
	@UserNum AS INT = 0,
	@AuthNum AS INT,
	@AuthType AS CHAR(1) = '1',
	@Type AS INT = -1
AS
BEGIN

	SET NOCOUNT ON

	DECLARE @FromIndexNum INT
	DECLARE @ToIndexNum INT
	DECLARE @tm_GroupNum INT
	DECLARE @tm_Depth INT
	DECLARE @tm_ParentGroup INT
	
	DECLARE @UserType INT
	
	DECLARE @tm_MonitorPage INT
	DECLARE @TempQuery VARCHAR(1000)
	Set @tm_MonitorPage = 0
	
	CREATE TABLE #tm_Tree(
		GroupID VARCHAR(32) PRIMARY KEY,
		NodeCaption NVARCHAR(64),
		ParentGroupID VARCHAR(32),
		Depth INT,
		MenuType INT,
		ViewType INT,
		IsGroup INT,
		Param1 NVARCHAR(64),
		Param2 NVARCHAR(64),
		Param3 NVARCHAR(64)
	)

	CREATE TABLE #tm_MyGroup(
		GroupNum INT PRIMARY KEY,
		ParentGroup INT,
		IndexNum INT,
		Depth INT
	)

	CREATE TABLE #NormalUserRights(
		ExtNum VARCHAR(10),
		ExtName VARCHAR(50),
		GroupNum INT,
		ParentGroup INT,
		Depth INT,
		IndexNum INT
	)
	INSERT INTO #tm_MyGroup
	SELECT	G.GroupNum, G.ParentGroup, G.IndexNum, G.Depth
	FROM tbl_Group G LEFT JOIN tbl_UserGroup AG ON G.GroupNum = AG.GroupNum AND G.Status  = 1
	WHERE AG.UserNum = @UserNum AND AG.CreateID = 0 
	
	SET @FromIndexNum = -1

	WHILE(@FromIndexNum IS NOT NULL)
	BEGIN
		SET @tm_GroupNum = NULL
		SELECT @FromIndexNum = MIN(IndexNum) FROM #tm_MyGroup

		IF(@FromIndexNum IS NOT NULL)
		BEGIN
			SELECT @tm_GroupNum = GroupNum, @tm_Depth = Depth, @tm_ParentGroup = ParentGroup FROM  #tm_MyGroup WHERE IndexNum = @FromIndexNum
			SELECT @ToIndexNum = MIN(IndexNum) FROM tbl_Group WHERE Status = 1 AND IndexNum >  @FromIndexNum AND Depth <= @tm_Depth

			IF(@ToIndexNum IS NULL)
				SELECT @ToIndexNum = MAX(IndexNum)+1 FROM tbl_Group
			
			INSERT INTO #tm_Tree
			SELECT	CONVERT(VARCHAR(32), GroupNum), GroupName, CONVERT(VARCHAR(32),  ParentGroup), Depth, 1, 0, 1, CONVERT(NVARCHAR(64), GroupNum), '', CONVERT(NVARCHAR(64), IndexNum)
			FROM tbl_Group
			WHERE Status = 1 

			WHILE (@tm_Depth > 0)
			BEGIN
				INSERT INTO #tm_Tree
					SELECT	CONVERT(VARCHAR(32), GroupNum), GroupName, CONVERT(VARCHAR(32),  ParentGroup), Depth, 0, 0, 1, CONVERT(NVARCHAR(64), GroupNum), '', CONVERT(NVARCHAR(64), IndexNum)
					FROM tbl_Group
					WHERE	GroupNum = @tm_ParentGroup	AND	NOT GroupNum IN (SELECT CONVERT(INT, GroupID) FROM #tm_Tree)

				SELECT @tm_ParentGroup = ParentGroup FROM tbl_Group WHERE GroupNum =  @tm_ParentGroup
				SET @tm_Depth = @tm_Depth - 1
			END
			DELETE FROM #tm_MyGroup WHERE IndexNum = @FromIndexNum
		END

	END

	DROP TABLE #tm_MyGroup
	IF(@AuthNum = 5)-- added for evaluations page to show only users
		BEGIN
			SET @TempQuery = 'INSERT INTO #NormalUserRights
			SELECT	A.UserNum,	A.UserName, EG.GroupNum,G.ParentGroup,G.Depth,G.IndexNum
			FROM tbl_UserGroup EG LEFT JOIN tbl_Group G ON G.Status =1 AND G.GroupNum = EG.GroupNum 		
			, tbl_NormalRight SR LEFT JOIN tbl_User A  ON SR.SelectedUserNum = A.UserNum AND SR.MainUserNum =' + CONVERT(VARCHAR(10),@UserNum)+'
			WHERE EG.UserNum = A.UserNum AND SR.MainUserNum = '+ CONVERT(VARCHAR(10),@UserNum)+' AND SUBSTRING(SR.AccessRight, '+ CONVERT(VARCHAR(10),@AuthNum)+', 1) =' + CONVERT(VARCHAR(10), @AuthType)
		END
	ELSE
		BEGIN
			SET @TempQuery = 'INSERT INTO #NormalUserRights
			SELECT	EG.Ext,	E.ExtName, 	EG.GroupNum,G.ParentGroup,G.Depth,G.IndexNum FROM tbl_channel E, tbl_UserGroup EG
			LEFT JOIN tbl_Group G ON G.Status =1 AND G.GroupNum = EG.GroupNum
			LEFT JOIN tbl_NormalRight SR ON EG.Ext COLLATE DATABASE_DEFAULT = SR.SelectedExt COLLATE DATABASE_DEFAULT AND SR.MainUserNum = '+ CONVERT(VARCHAR(10),@UserNum)+'
			WHERE E.Ext = EG.Ext AND SR.MainUserNum = '+ CONVERT(VARCHAR(10),@UserNum)+' AND SUBSTRING(SR.AccessRight, '+ CONVERT(VARCHAR(10),@AuthNum)+', 1) = '+ CONVERT(VARCHAR(10),@AuthType)
		END
		
	EXEC (@TempQuery)

	IF(@AuthNum = 5)--Get User Tree -- added for evaluations page to show only users
		BEGIN
			INSERT INTO #tm_Tree
			SELECT	CONVERT(VARCHAR, MS.GroupNum) + 'CH' + Convert(varchar(10), E.UserNum),  MS.ExtName, CONVERT(VARCHAR(32),  MS.GroupNum), MS.Depth+1, 1, 1, 0, CONVERT(NVARCHAR(64), MS.GroupNum), CONVERT(NVARCHAR(64), E.UserNum),  CONVERT(NVARCHAR(64), MS.IndexNum)
			FROM #NormalUserRights  MS
			LEFT JOIN tbl_User E ON MS.ExtNum = Convert(varchar(10), E.UserNum) AND E.Status = 1 
		END
		
	ELSE IF(@Type = 0)--Caption: Group
		BEGIN
			INSERT INTO #tm_Tree
			SELECT	CONVERT(VARCHAR, MS.GroupNum) + 'CH' + E.Ext,  E.Ext, CONVERT(VARCHAR(32),  MS.GroupNum), MS.Depth+1, 1, 1, 0, CONVERT(NVARCHAR(64), MS.GroupNum), CONVERT(NVARCHAR(64), E.Ext),  CONVERT(NVARCHAR(64), MS.IndexNum)
			FROM #NormalUserRights  MS
			LEFT JOIN tbl_channel E ON MS.ExtNum COLLATE DATABASE_DEFAULT = E.Ext COLLATE DATABASE_DEFAULT AND E.Status = 1 
			WHERE E.Ext IS NOT NULL 
		END

	ELSE IF(@Type = 1)--Caption: Channel
		BEGIN
			INSERT INTO #tm_Tree
			SELECT	CONVERT(VARCHAR, MS.GroupNum) + 'CH' + E.Ext,  dbo.GetChannelDisplayName( E.Ext, E.ExtName), CONVERT(VARCHAR(32),  MS.GroupNum), MS.Depth+1, 1, 1, 0, CONVERT(NVARCHAR(64), MS.GroupNum), CONVERT(NVARCHAR(64), E.Ext),  CONVERT(NVARCHAR(64), MS.IndexNum)
			FROM	#NormalUserRights  MS 
			LEFT JOIN tbl_channel E ON MS.ExtNum COLLATE DATABASE_DEFAULT = E.Ext COLLATE DATABASE_DEFAULT AND E.Status = 1 
			WHERE E.Ext IS NOT NULL 
			SET @tm_MonitorPage = 1			
		END
			
	ELSE IF(@Type = 2)
		BEGIN
			INSERT INTO #tm_Tree
			SELECT	CONVERT(VARCHAR, MS.GroupNum) + 'CH' + E.Ext, dbo.GetChannelDisplayName( E.Ext, E.ExtName), CONVERT(VARCHAR(32),  MS.GroupNum), MS.Depth+1, 1, 1, 0, CONVERT(NVARCHAR(64), MS.GroupNum), CONVERT(NVARCHAR(64), E.Ext),  CONVERT(NVARCHAR(64), MS.IndexNum)
			FROM #NormalUserRights  MS 
			LEFT JOIN tbl_channel E ON MS.ExtNum COLLATE DATABASE_DEFAULT= E.Ext COLLATE DATABASE_DEFAULT AND E.Status = 1 
			WHERE E.Ext IS NOT NULL 
		END
	ELSE IF(@Type = 4)
		BEGIN
			INSERT INTO #tm_Tree
			SELECT	CONVERT(VARCHAR, MS.GroupNum) + 'CH' + E.Ext,  dbo.GetChannelDisplayName( E.Ext, E.ExtName), CONVERT(VARCHAR(32),  MS.GroupNum), MS.Depth+1, 1, 1, 0, CONVERT(NVARCHAR(64), MS.GroupNum), CONVERT(NVARCHAR(64), E.Ext),  CONVERT(NVARCHAR(64), MS.IndexNum)
			FROM	#NormalUserRights  MS 
			LEFT JOIN tbl_channel E ON MS.ExtNum COLLATE DATABASE_DEFAULT = E.Ext COLLATE DATABASE_DEFAULT AND E.Status = 1 
			WHERE  E.Ext IS NOT NULL 
		END
	
	SET NOCOUNT OFF
	IF(@tm_MonitorPage = 1)
		BEGIN
			IF(@Type = -1)
				BEGIN
					SELECT * FROM #tm_Tree ORDER BY NodeCaption
				END
			ELSE
				BEGIN
					SELECT distinct t1.* from  #tm_Tree t1
					join (SELECT param1  FROM #tm_Tree WHERE param1 <> '' AND param2 <> '')t2 on t1.param1 = t2.param1 AND 
					t1.param1 = t2.param1
					join (SELECT param1 FROM #tm_Tree WHERE param1 <> '' AND param2 = '') t3 on t2.param1 = t3.param1 AND 
					t1.param1 = t3.param1
				END
		END
	ELSE
		BEGIN
			IF(@Type = -1)
				BEGIN
					SELECT * FROM #tm_Tree ORDER BY ViewType, right('00000000000000000000000000000000'+NodeCaption, 32)
				END
			ELSE
				BEGIN
					SELECT distinct t1.* from  #tm_Tree t1
					join (SELECT param1  FROM #tm_Tree WHERE param1 <> '' AND param2 <> '')t2 on t1.param1 = t2.param1 AND 
					t1.param1 = t2.param1
					join (SELECT param1 FROM #tm_Tree WHERE param1 <> '' AND param2 = '') t3 on t2.param1 = t3.param1 AND 
					t1.param1 = t3.param1
				END
		END

	SET NOCOUNT ON
	DROP TABLE #NormalUserRights
	DROP TABLE #tm_Tree

	SET NOCOUNT OFF

END
GO
------------------------------------------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS OFF
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_DeleteSurvey]'))
	drop proc [dbo].sp_DeleteSurvey
GO
CREATE PROC [dbo].[sp_DeleteSurvey]	
	@SID AS BIGINT	-- Survey ID
AS
	Declare @QID Int;
	BEGIN
		Declare QCursor Cursor FOR
		SELECT ID from tbl_Questions where SurveyID = @SID;

		Open QCursor;

		Fetch Next	From QCursor Into @QID

		While (@@Fetch_Status = 0) BEGIN
			DELETE FROM tbl_Options where QuestionID = @QID			
			Fetch Next From QCursor Into @QID	
		END
			
		CLOSE QCursor
				
		DELETE FROM tbl_Questions where SurveyID = @SID
		DELETE FROM tbl_Survey where ID = @SID		
	END
GO
------------------------------------------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS OFF
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_DeleteQuestion]'))
	drop proc [dbo].sp_DeleteQuestion
GO
CREATE PROC [dbo].[sp_DeleteQuestion]	
	@QID AS BIGINT, --Question ID
	@SID AS BIGINT	-- Survey ID
AS
	BEGIN
		DELETE FROM tbl_Options where QuestionID = @QID
		DELETE FROM tbl_Questions where ID = @QID
	END
GO
------------------------------------------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS OFF
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_AddUpdateQuestion]'))
	drop proc [dbo].sp_AddUpdateQuestion
GO
CREATE PROC [dbo].[sp_AddUpdateQuestion]
	@Question as VARCHAR(1000),
	@QuestionType as tinyint,
	@bCommentsField as bit = 0,
	@QuestionRate as float,
	@OptionsCount as int,
	@DisplayOrder as int,
    @CreatedBy as int,
    @SurveyID as int,
    @UpdateQID as int = 0
AS
	BEGIN
	IF @UpdateQID > 0
		BEGIN
			UPDATE tbl_Questions
				SET Question = @Question
				  ,QuestionType = @QuestionType
				  ,bCommentsField = @bCommentsField
				  ,QuestionRate = @QuestionRate
				  ,DisplayOrder = @DisplayOrder
				  ,OptionsCount = @OptionsCount
				  ,CreatedBy = @CreatedBy
			WHERE ID = @UpdateQID
			
			DELETE FROM tbl_Options WHERE QuestionID = @UpdateQID
			SELECT @UpdateQID
		END
	ELSE
		BEGIN
			INSERT INTO tbl_Questions
				   (Question
				   ,QuestionType
				   ,bCommentsField
				   ,QuestionRate
				   ,OptionsCount
				   ,DisplayOrder
				   ,CreatedBy
				   ,SurveyID)
			 VALUES
				   (@Question
				   ,@QuestionType
				   ,@bCommentsField
				   ,@QuestionRate
				   ,@OptionsCount
				   ,@DisplayOrder
				   ,@CreatedBy
				   ,@SurveyID)
			SELECT IDENT_CURRENT('tbl_Questions')
		END
	END
GO
------------------------------------------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS OFF
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_AddSurvey]'))
	drop proc [dbo].sp_AddSurvey
GO
CREATE PROC [dbo].[sp_AddSurvey]
	@Title as VARCHAR(200), 
	@Description as VARCHAR(500),
	@StartOn as datetime, 	
	@ExpireOn as datetime,
	@CreatedBy as int,
	@Publish as tinyint = 0, 
	@IsShared as bit = 1,
	@SurveyID as int = 0,
	@IsActiveOnExpiry as bit = 0
AS
BEGIN
	IF(@SurveyID = 0)
		BEGIN
			INSERT INTO tbl_Survey
				   (Title
				   ,Description
				   ,CreatedOn
				   ,StartOn
				   ,ExpireOn
				   ,CreatedBy
				   ,Publish
				   ,IsShared
				   ,IsActiveOnExpiry)
			 VALUES
				   (@Title
				   ,@Description
				   ,GETDATE()
				   ,@StartOn
				   ,@ExpireOn
				   ,@CreatedBy
				   ,@Publish
				   ,@IsShared
				   ,@IsActiveOnExpiry)
		           
			  SELECT SCOPE_IDENTITY() as ServeyID
		END
	ELSE
		BEGIN
			UPDATE tbl_Survey
				   SET Title = @Title
				   ,Description = @Description
				   ,StartOn = @StartOn
				   ,ExpireOn = @ExpireOn
				   ,Publish = @Publish
				   ,IsShared = @IsShared
				   ,IsActiveOnExpiry = @IsActiveOnExpiry
				   where ID = @SurveyID
				   
			SELECT @SurveyID AS SurveyID
		END
END
GO
------------------------------------------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS OFF
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_AddOption]'))
	drop proc [dbo].sp_AddOption
GO
CREATE PROC [dbo].[sp_AddOption]
	@OptionText as VARCHAR(500), 
	@OptionRate as FLOAT, 	
	@QuestionID AS BIGINT
AS
	BEGIN
		INSERT INTO tbl_Options
			   (OptionText
			   ,OptionRate
			   ,QuestionID)
		 VALUES
			   (@OptionText,
			    @OptionRate,
			    @QuestionID)
	END
GO
------------------------------------------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS OFF
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_AddCallToEvaluation]'))
	drop proc [dbo].sp_AddCallToEvaluation
GO
CREATE PROC [dbo].[sp_AddCallToEvaluation]
	@CallID AS NVARCHAR(64),
	@UserNum AS INT,
	@IsShared AS BIT = False,
	@IsEvaluated AS BIT = False,
	@SurveyID AS INT = 0	
AS
	BEGIN
		DECLARE @myCounter int = 0
		SELECT @myCounter = COUNT(*) FROM tbl_Evaluations WHERE CallID = @CallID AND UserNum = @UserNum AND SurveyID = @SurveyID
		IF @myCounter = 0
			BEGIN
				INSERT INTO tbl_Evaluations( CallID, IsShared, IsEvaluated, SurveyID, UserNum, StartDate, EndDate )
				 VALUES
					   ( @CallID, @IsShared, @IsEvaluated, @SurveyID,@UserNum, GETDATE(), GETDATE() )
			END
		ELSE
			BEGIN
				RAISERROR('Alread added', 16, 1)
				RETURN -1
			END
	END               
GO
------------------------------------------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS OFF
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_SurveyList]'))
	drop proc [dbo].sp_SurveyList
GO
CREATE PROC [dbo].[sp_SurveyList]	
	@TopCount AS INT = 100,
	@SORTINDEX AS NVARCHAR(50),
	@PageNum AS INT
AS
	
	BEGIN
		DECLARE @sqlSTR NVARCHAR(4000)
		
		SELECT COUNT(*) FROM tbl_Survey
			
		SET @sqlSTR = 'SELECT TOP ' + @TopCount + ' S.ID AS [IDX],' + char(13)
		SET @sqlSTR = @sqlSTR + 'S.TITLE AS [TitleIDX],' + char(13)
		SET @sqlSTR = @sqlSTR + '(SELECT COUNT(*) FROM tbl_Questions where S.ID = SurveyID) QUESTIONIDX,' + char(13)
		SET @sqlSTR = @sqlSTR + '(SELECT SUM(QuestionRate) FROM tbl_Questions where S.ID = SurveyID) ScoreIDX,' + char(13)
		SET @sqlSTR = @sqlSTR + 'S.CreatedOn AS [StartOnIDX],' + char(13)
		SET @sqlSTR = @sqlSTR + 'S.ExpireOn AS [ExpireOnIDX],' + char(13)
		SET @sqlSTR = @sqlSTR + 'S.Publish AS [PublishIDX]' + char(13)
		SET @sqlSTR = @sqlSTR + 'FROM tbl_Survey S LEFT JOIN tbl_Questions Q ON S.ID = Q.SurveyID' + char(13)
		SET @sqlSTR = @sqlSTR + 'ORDER BY ' + @SORTINDEX + char(13)
	END
GO
------------------------------------------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS OFF
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_AddQuestion]'))
	drop proc [dbo].sp_AddQuestion
GO
CREATE PROC [dbo].[sp_AddQuestion]
	@Question as VARCHAR(1000),
	@QuestionType as tinyint,
	@bCommentsField as bit = 0,
	@QuestionRate as float,
	@OptionsCount as int,
	@DisplayOrder as int,
    @CreatedBy as int,
    @SurveyID as int
AS
	BEGIN
		INSERT INTO tbl_Questions
			   (Question
			   ,QuestionType
			   ,bCommentsField
			   ,QuestionRate
			   ,OptionsCount
			   ,DisplayOrder
			   ,CreatedBy
			   ,SurveyID)
		 VALUES
			   (@Question
			   ,@QuestionType
			   ,@bCommentsField
			   ,@QuestionRate
			   ,@OptionsCount
			   ,@DisplayOrder
			   ,@CreatedBy
			   ,@SurveyID)
		SELECT IDENT_CURRENT('tbl_Questions')
	END
GO
------------------------------------------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS OFF
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_AddAnswer]'))
	drop proc [dbo].sp_AddAnswer
GO
CREATE PROC [dbo].[sp_AddAnswer]
	@OptionID as bigint
   ,@EvalutionID as bigint
   ,@AnsweredBy as int
   ,@QuestionID as bigint
AS
	BEGIN
		INSERT INTO tbl_Answers
           (OptionID
           ,EvalutionID
           ,AnsweredBy
           ,QuestionID)
     VALUES
           (@OptionID
           ,@EvalutionID
           ,@AnsweredBy
           ,@QuestionID)
	END
GO
----------------------------------------------------------------------------------------------------------------------------------------
USE [ASLogger]
GO
SET ANSI_NULLS OFF
GO
SET QUOTED_IDENTIFIER OFF
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[fn_IsCallEvaluated]'))
	drop FUNCTION [dbo].fn_IsCallEvaluated
GO

CREATE FUNCTION [dbo].[fn_IsCallEvaluated] (@UserNum VARCHAR(32), @RECID VARCHAR(40))
	RETURNS INT
AS
BEGIN
	
	DECLARE @Result INT

	SELECT
		@Result = count(*)
	FROM
		tbl_Evaluations
	WHERE
		CallID = @RECID
		AND
		UserNum = @UserNum

	RETURN @Result

END
GO
